@@ -1,7 +1,7 @@
 /*
- * Copyright (c) 2000    Paul Kinnucan
+ * Copyright (c) 2000, 2001    Paul Kinnucan
  *
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
  */
 
 package jde.debugger.command;
@@ -44,9 +44,9 @@ import com.sun.jdi.NativeMethodException;
  *
  * @author Amit Kumar
  * @author Paul Kinnucan
- * @version $Revision: 1.2 $
+ * @version $Revision: 1.3 $
  */
- public class GetLocals extends DebugApplicationCommand {
+ public class GetLocals extends DebugProcessCommand {
   
   /**
    *
@@ -65,7 +65,7 @@ import com.sun.jdi.NativeMethodException;
        Long uniqueID = Etc.safeGetLong(args.remove(0), "thread ID");
        int frameIndex = Etc.safeGetint(args.remove(0), "frame index");
 	    
-       Object oRef = app.getStore().get(uniqueID);
+       Object oRef = proc.getStore().get(uniqueID);
        if (oRef == null) {
 	 throw new JDEException("No such thread exists");
        } else if (!(oRef instanceof ThreadReference)) {
@@ -98,14 +98,14 @@ import com.sun.jdi.NativeMethodException;
        try {
 	 localVariableValues = 
 	   Rep.getLocalVariableValueMapRep(frame.getValues(frame.visibleVariables()), 
-					   app.getStore());
+					   proc.getStore());
        } catch (AbsentInformationException ex) {
 	 throw new JDEException("Local variable information not available: compile with -g");
        } catch (NativeMethodException ex) {
 	 throw new JDEException("Can't access local variables in native methods");
        }
 
-       app.signalCommandResult(cmdID, localVariableValues);
+       jde.signalCommandResult(procID, cmdID, localVariableValues);
 				    
      } finally {
        if (weSuspendedThread && (tRef != null)) tRef.resume();
@@ -119,8 +119,11 @@ import com.sun.jdi.NativeMethodException;
 
 /*
  * $Log: GetLocals.java,v $
- * Revision 1.2  2001/02/12 06:27:24  paulk
- * Updated for JDE-2.2.7.
+ * Revision 1.3  2001/08/16 03:29:02  andyp
+ * Update to JDE 2.2.7.1
+ *
+ * Revision 1.3  2001/03/24 05:42:36  paulk
+ * Updated to reflect reorganization of debugger code.
  *
  * Revision 1.2  2000/08/14 02:42:16  paulk
  * DebugCommandFactory.java
