@@ -1,7 +1,7 @@
 /*
- * Copyright (c) 2000    Paul Kinnucan
+ * Copyright (c) 2000, 2001    Paul Kinnucan
  *
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
  */
 
 package jde.debugger.command;
@@ -43,9 +43,9 @@ import com.sun.jdi.InvalidStackFrameException;
  * </ul>
  *
  * @author Paul Kinnucan
- * @version $Revision: 1.2 $
+ * @version $Revision: 1.3 $
  */
- public class GetThis extends DebugApplicationCommand {
+ public class GetThis extends DebugProcessCommand {
   
   /**
    *
@@ -64,7 +64,7 @@ import com.sun.jdi.InvalidStackFrameException;
        Long uniqueID = Etc.safeGetLong(args.remove(0), "thread ID");
        int frameIndex = Etc.safeGetint(args.remove(0), "frame index");
 	    
-       Object oRef = app.getStore().get(uniqueID);
+       Object oRef = proc.getStore().get(uniqueID);
        if (oRef == null) {
 	 throw new JDEException("No such thread exists");
        } else if (!(oRef instanceof ThreadReference)) {
@@ -101,7 +101,7 @@ import com.sun.jdi.InvalidStackFrameException;
 	 throw new JDEException("Invalid stack frame.");
        } 
 
-       app.signalCommandResult(cmdID, Rep.getObjectRep(thisObj, app.getStore(), true));
+       jde.signalCommandResult(procID, cmdID, Rep.getObjectRep(thisObj, proc.getStore(), true));
 				    
      } finally {
        if (weSuspendedThread && (tRef != null)) tRef.resume();
@@ -115,8 +115,11 @@ import com.sun.jdi.InvalidStackFrameException;
 
 /*
  * $Log: GetThis.java,v $
- * Revision 1.2  2001/02/12 06:27:24  paulk
- * Updated for JDE-2.2.7.
+ * Revision 1.3  2001/08/16 03:29:03  andyp
+ * Update to JDE 2.2.7.1
+ *
+ * Revision 1.3  2001/03/24 05:42:36  paulk
+ * Updated to reflect reorganization of debugger code.
  *
  * Revision 1.2  2000/08/14 02:42:16  paulk
  * DebugCommandFactory.java
