@@ -1,8 +1,8 @@
 /*
  * Copyright (c) Paul Kinnucan 1998. All Rights Reserved.
  *
- * $Revision: 1.1 $ 
- * $Date: 2000/08/13 13:42:15 $ 
+ * $Revision: 1.2 $ 
+ * $Date: 2001/08/16 03:29:13 $ 
  *
  * MethodOverrideFactory is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,7 +33,7 @@ import java.util.Enumeration;
  * superclass.
  *
  * @author Paul Kinnucan
- * @version $Revision: 1.1 $
+ * @version $Revision: 1.2 $
  */
 
 public class MethodOverrideFactory extends MethodFactory
@@ -89,13 +89,10 @@ public class MethodOverrideFactory extends MethodFactory
     try {
 
       Class baseClass = Class.forName(baseClassName);
-      Class rootClass = Class.forName("java.lang.Object");
 
-      while (! baseClass.equals(rootClass)) {
+      while (baseClass != null) {
 
-	Class superclass = baseClass.getSuperclass();
-
-	Vector methods = overrideFactory.getMethods(superclass, methodName);
+	Vector methods = overrideFactory.getMethods(baseClass, methodName);
 
 	int n = methods.size();
 
@@ -113,7 +110,7 @@ public class MethodOverrideFactory extends MethodFactory
 	      overrideFactory.candidates.addElement(s);
 	  }
 	}
-	baseClass = superclass;
+	baseClass = baseClass.getSuperclass();
       }
       
       int n = overrideFactory.candidates.size();
@@ -130,8 +127,8 @@ public class MethodOverrideFactory extends MethodFactory
       }
       else
 	println("(error \"Could not find any method named " +
-		methodName + " in any superclass of " +
-		baseClassName + "\")");
+		methodName + " in " + baseClassName + 
+		" or any of its superclasses.\")");
 
     }
     catch (ClassNotFoundException ee) {
@@ -183,6 +180,13 @@ public class MethodOverrideFactory extends MethodFactory
     candidates.removeAllElements();
   }
 
+  public static void main (String[] args) {
+
+    getCandidateSignatures("jde.ui.design.command.Command","getName");
+     
+  } // end of main ()
+  
+
 
 } // MethodOverrideFactory
 
