@@ -5,18 +5,21 @@
 (autoload 'custom-add-loads "cus-load")
 
 (custom-add-loads 'jde-project '("jde-db" "jde-help" "jde-imenu" "jde-import" "jde-java-font-lock" "jde-make" "jde-parse" "jde-run" "jde"))
+(custom-add-loads 'jde-java-font-lock-faces '("jde-java-font-lock"))
 (custom-add-loads 'bsh '("beanshell"))
 (custom-add-loads 'jde-bug-window '("jde-bug"))
 (custom-add-loads 'jde-javadoc '("jde-javadoc-gen" "jde-javadoc"))
 (custom-add-loads 'jde-db-options '("jde-db"))
 (custom-add-loads 'jde-package '("jde-package"))
+(custom-add-loads 'font-lock-faces '("jde-java-font-lock"))
 (custom-add-loads 'jde-compile-options '("jde-compile"))
+(custom-add-loads 'tree-widget '("tree-widget"))
 (custom-add-loads 'jde-which-method '("jde-which-method"))
-(custom-add-loads 'jde '("jde-bug" "jde-compile" "jde-db" "jde-gen" "jde-javadoc" "jde-run" "jde-which-method" "jde"))
+(custom-add-loads 'jde '("jde-bug" "jde-compile" "jde-db" "jde-gen" "jde-javadoc" "jde-package" "jde-run" "jde-which-method" "jde"))
 (custom-add-loads 'jde-gen '("jde-gen"))
-(custom-add-loads 'jde-run-options '("beanshell" "jde-run"))
-(custom-add-loads 'font-lock-highlighting-faces '("jde-java-font-lock"))
+(custom-add-loads 'jde-run-options '("jde-run"))
+(custom-add-loads 'widgets '("tree-widget"))
 (custom-add-loads 'jde-bug '("jde-bug" "jde-dbs"))
-(custom-add-loads 'tools '("jde-package" "jde"))
+(custom-add-loads 'tools '("jde"))
 
 ;;; custom-load.el ends here
