@@ -1,11 +1,11 @@
 ;;; jde-bug.el -- JDEbug Interface
-;; $Revision: 1.2 $ $Date: 2001/02/12 05:38:22 $ 
+;; $Revision: 1.3 $ $Date: 2001/08/16 03:29:14 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
 ;; Keywords: java, tools
 
-;; Copyright (C) 1997, 1998, 1999, 2000 Paul Kinnucan.
+;; Copyright (C) 1997, 1998, 1999, 2000, 2001 Paul Kinnucan.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -143,8 +143,8 @@ a local host: 127.0.0.1 ."
   :type 'string)
 
 
-(defcustom jde-bug-debugger-command-timeout 10
-  "*Length of time the JDE waits for a response from the debugger to a command."
+(defcustom jde-bug-debugger-command-timeout 30
+  "*Length of time in seconds the JDE waits for a response from the debugger to a command."
   :group 'jde-bug
   :type 'integer)
 
@@ -1422,6 +1422,16 @@ requests to cancel."
 			      :initform "access"
 			      :documentation
 			      "Watch type: field access or modification.")
+   (object-class              :initarg :object-class
+                              :type string
+			      :initform ""
+			      :documentation
+			      "Default value of class to watch.")
+   (field                     :initarg :field
+			      :type string
+			      :initform ""
+			      :documentation
+			      "Default value of the field to watch.")
    (object-class-widget       :initarg :object-class-widget
 			      :documentation
 			      "Widget specifying class of objects to watch.")
@@ -1466,6 +1476,7 @@ requests to cancel."
   (oset this object-class-widget
 	(widget-create
 	 'editable-field
+	 :value (oref this object-class)
 	 :format "  %t:  %v\n  %h \n\n"
 	 :size 40
 	 :tag "Class"
@@ -1476,6 +1487,7 @@ May be a wild card pattern of the form *.name. This allows you to omit a package
   (oset this field-name-widget
 	(widget-create
 	 'editable-field
+	 :value (oref this field)
 	 :format "  %t:  %v\n  %h \n\n"
 	 :size 40
 	 :tag "Field name"
@@ -1510,7 +1522,7 @@ Execution of the process is suspended only if the expression is true. The expres
 	(widget-create
 	 '(choice
 	   :tag "Thread Suspension Policy"
-	   :value "none"
+	   :value "all"
 	   :format "  %t: %[Options%] %v  %h\n\n"
 	   :doc "Specify which threads to suspend on field access or modification."
 	   (const "all")
@@ -1540,8 +1552,7 @@ Execution of the process is suspended only if the expression is true. The expres
 	   (string
 	    :format "%t: %v"
 	    :size 40
-	    :tag "Filter")))) 
-  )
+	    :tag "Filter")))))
 
 (defmethod jde-dialog-ok ((this jde-bug-watch-field-dialog))
   (let* ((obj-class (widget-value (oref this object-class-widget)))
@@ -1588,15 +1599,26 @@ Execution of the process is suspended only if the expression is true. The expres
   "Request that the debugger watch for access of a
 field of an object or class of objects."
   (interactive)
-  (let ((dialog (jde-bug-watch-field-dialog "watch field dialog")))
+  (let ((dialog 
+	 (jde-bug-watch-field-dialog 
+	  "watch field dialog"
+	  :object-class (concat 
+			 "*." 
+			 (car (jde-parse-get-innermost-class-at-point)))
+	  :field (thing-at-point 'symbol))))
     (jde-dialog-show dialog)))
 
 (defun jde-bug-watch-field-modification ()
   "Request that the debugger watch for modifiction of a
 field of an object or class of objects."
   (interactive)
-  (let ((dialog (jde-bug-watch-field-dialog "watch field dialog" 
-					    :watch-type "modification")))
+  (let ((dialog (jde-bug-watch-field-dialog 
+		 "watch field dialog" 
+		 :watch-type "modification"
+		 :object-class (concat 
+				"*." 
+				(car (jde-parse-get-innermost-class-at-point)))
+		 :field (thing-at-point 'symbol))))
     (jde-dialog-show dialog)))
 
 
@@ -2167,7 +2189,8 @@ to creae the exception object."
     (error "jde-bug-jpda-directory variable is not set.")
     nil)
    ((not (file-exists-p 
-	  (expand-file-name "lib/jpda.jar" jde-bug-jpda-directory)))
+	  (expand-file-name "lib/jpda.jar" (jde-normalize-path
+					    'jde-bug-jpda-directory))))
     (error "Cannot find JPDA jar file at %s"
 	     (expand-file-name "lib/jpda.jar" jde-bug-jpda-directory))
     nil)
@@ -2219,7 +2242,7 @@ to set another process as the target process."
 	     (succeededp t))
 	(jde-dbs-proc-set-add jde-dbs-the-process-registry process)
 	(if (not (string= jde-bug-jre-home ""))
-	    (oset launch :jre-home jde-bug-jre-home))
+	    (oset launch :jre-home (jde-normalize-path 'jde-bug-jre-home)))
 	(oset jde-dbs-the-process-registry :target-process process)
 	(when (not (jde-dbs-cmd-exec launch))	    
 	  (jde-dbs-proc-move-to-morgue process)
@@ -2587,8 +2610,20 @@ pane of the JDEBug's three-pane window configuration."
 (provide 'jde-bug)
 
 ;; $Log: jde-bug.el,v $
-;; Revision 1.2  2001/02/12 05:38:22  paulk
-;; JDE 2.2.7
+;; Revision 1.3  2001/08/16 03:29:14  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.61  2001/04/23 04:55:52  paulk
+;; The watchpoint command now defaults to the field at point and to "all" as the program suspension policy when a field is accessed or modified.
+;;
+;; Revision 1.60  2001/04/16 05:43:47  paulk
+;; Normalized paths. Thanks to Nick Sieger.
+;;
+;; Revision 1.59  2001/04/02 02:49:50  paulk
+;; Increased default debugger command timeout factor to 30 seconds.
+;;
+;; Revision 1.58  2001/03/13 03:54:00  paulk
+;; Update copyright.
 ;;
 ;; Revision 1.57  2000/12/18 05:22:45  paulk
 ;; *** empty log message ***
