@@ -1,5 +1,5 @@
 ;;; jde-compile.el -- Integrated Development Environment for Java.
-;; $Revision: 1.4 $ $Date: 2001/02/20 05:29:19 $ 
+;; $Revision: 1.5 $ $Date: 2001/08/16 03:29:14 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -85,7 +85,7 @@ file to be saved in the directory C:\\users\\dac\\classes. If your class
 is in the package demos\\awt, the class files would be placed in directory
 C:\\users\\dac\\classes\\demos\\awt."
   :group 'jde-compile-options
-  :type 'file)
+  :type 'directory)
 
 (defcustom jde-compile-option-deprecation nil
   "*Warn use or override of a deprecated member or class. 
@@ -273,23 +273,6 @@ source and class files.
   :group 'jde-compile-options
   :type 'boolean)
 
-;; Cygwin style paths will not be understood by the java tools.  Call
-;; jde-convert-cygwin-path before passing path information to a
-;; java tool.
-(defun jde-build-path-arg (path-type path-list quote)
-"Build a path argument from a list of paths."
-  (let ((path 
-	 (mapconcat (lambda (x) x) path-list jde-classpath-separator)))
-    ;; CFH - Call jde-convert-cygwin-path to handle cygwin paths
-    (setq path (jde-convert-cygwin-path path jde-classpath-separator))
-    (if quote
-        (setq path (concat "\"" path "\"")))
-    (setq path (concat path-type " " path))))
-
-
-(defun jde-build-classpath-arg (path-list quote)
-"Build a classpath from a list of paths."
- (jde-build-path-arg "-classpath" path-list quote))
 
 (defun jde-get-compile-options ()
 "Constructs a command-line argument string for compiler.
@@ -302,18 +285,22 @@ settings.
     (if jde-compile-option-classpath
 	(setq options 
 	      (jde-build-classpath-arg
-	       jde-compile-option-classpath jde-quote-classpath))
+	       jde-compile-option-classpath
+	       jde-quote-classpath
+	       'jde-compile-option-classpath))
       (if jde-global-classpath
 	  (setq options
 		(jde-build-classpath-arg
-		 jde-global-classpath jde-quote-classpath))))
+		 jde-global-classpath
+		 jde-quote-classpath
+		 'jde-global-classpath))))
 
     (if jde-compile-option-sourcepath
 	(setq options 
 	      (concat options " "
 	      (jde-build-path-arg
 	       "-sourcepath"
-	       jde-compile-option-sourcepath 
+	       'jde-compile-option-sourcepath 
 	       jde-quote-classpath))))
 
     (if jde-compile-option-bootclasspath
@@ -321,7 +308,7 @@ settings.
 	      (concat options " "
 	      (jde-build-path-arg
 	       "-bootclasspath"
-	       jde-compile-option-bootclasspath 
+	       'jde-compile-option-bootclasspath 
 	       jde-quote-classpath))))
 
     (if jde-compile-option-extdirs
@@ -329,7 +316,7 @@ settings.
 	      (concat options " "
 	      (jde-build-path-arg
 	       "-extdirs"
-	       jde-compile-option-extdirs
+	       'jde-compile-option-extdirs
 	       jde-quote-classpath))))
 
     ;; Debug option.
@@ -366,7 +353,7 @@ settings.
 	(setq options
 	      (concat options 
 		" -d "
-		(jde-normalize-path jde-compile-option-directory))))
+		(jde-normalize-path 'jde-compile-option-directory))))
 
     (if jde-compile-option-deprecation
 	(setq options (concat options " -deprecation")))
@@ -468,8 +455,20 @@ history enabled."
 
 ;; Change History
 ;; $Log: jde-compile.el,v $
-;; Revision 1.4  2001/02/20 05:29:19  paulk
-;; JDE 2.27 updates
+;; Revision 1.5  2001/08/16 03:29:14  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.14  2001/04/16 05:47:33  paulk
+;; Normalized paths. Thanks to Nick Sieger.
+;;
+;; Revision 1.13  2001/04/11 03:23:18  paulk
+;; Updated to resolve relative paths relative to the project file that defines them. Thanks to Nick Sieger.
+;;
+;; Revision 1.12  2001/04/02 02:42:58  paulk
+;; Remove extraneous definition of jde-build-classpath-arg.
+;;
+;; Revision 1.11  2001/03/13 04:03:47  paulk
+;; Changed the type of jde-compile-option-directory from string to directory to permit path completion.
 ;;
 ;; Revision 1.10  2001/02/20 05:15:10  paulk
 ;; You can now use environment variables, tilde notation, and cygwin syntax in jde-compile-option-directory path.
