@@ -1,5 +1,5 @@
 ;;; jde-complete.el -- Smart completion for the JDE
-;; $Revision: 1.2 $ 
+;; $Revision: 1.3 $ 
 
 ;; Author: Rodrigo Reyes <reyes@chez.com>
 ;; Maintainers: Rodrigo Reyes, Paul Kinnucan, Howard Spector, 
@@ -336,6 +336,7 @@ name NAME and the package list IMPORT where to look at."
 	(setq index (1+ index)))
     (substring s index)))
 
+;; Can this function be reimplemented to use regular expressions?
 (defun jde-complete-isolate-before-matching-of-last-car (s)
   "Returns the right expression that needs completion in S." 
   (let* ((index (length s)) stop (paren 0) (bracket 0) curcar)
@@ -357,6 +358,7 @@ name NAME and the package list IMPORT where to look at."
 	  (setq stop t))) 
     (substring s 0 index)))
 
+;; Can this function be reimplemented to use regular expressions?
 (defun jde-complete-java-variable-at-point ()
   "Returns a list (VAR PARTIAL) where VAR.PARTIAL is the partially completed method or field
 name at point. For example, suppose obj.f1.ge were the name at point. This function would return
@@ -373,22 +375,43 @@ the list (obj.f1 ge)."
 	  second-part
           (bracket-count 0)
           (paren-count 0))
+
+      ;; Move cursor to the beginning of the partially
+      ;; completed part of the expression, e.g., move point
+      ;; from
+      ;;
+      ;;   obj.f1.ge
+      ;;            ^
+      ;; to
+      ;;
+      ;;   obj.f1.ge
+      ;;         ^
+      ;;
       (setq curcar (char-before))
       (while (null found)
 	(cond 
-	 ((or (and (>= curcar ?a) (<= curcar ?z))
-	      (and (>= curcar ?A) (<= curcar ?Z))
+	 ((or (and (>= curcar ?a) (<= curcar ?z)) ; a-z
+	      (and (>= curcar ?A) (<= curcar ?Z)) ; A-z
 	      (and (>= curcar ?0) (<= curcar ?9))
 	      (>= curcar 127)
-	      (member curcar '(?_ ?\\ )))
+	      (member curcar '(?_ ?\\ ))) ;; _ \
 	  (forward-char -1))
 	 ((eq ?. curcar)
 	  (setq found (point)))
 	 (t
 	  (setq found t)))
 	(setq curcar (char-before)))
-      ;;
       (setq intermediate-point (point))
+      ;; Now move point to the beginning of the expression, e.g.,
+      ;; from
+      ;;
+      ;;  obj.f1.ge
+      ;;        ^
+      ;; to
+      ;;
+      ;;  obj.f1.ge
+      ;; ^
+      ;;
       (if (not (eq t found))
 	  (progn 
 	    (setq curcar (char-before))
@@ -495,35 +518,6 @@ jde.util.Completion.getClassInfo function."
 		    (+ (marker-position jde-complete-current-beginning) 
 		       (length completion))))))
 
-;; (defun jde-complete-popup-xemacs-completion-menu (completion-list)
-;;   (let* ((items
-;; 	  (sort
-;; 	   ;; Change each item in the completion list from the form
-;; 	   ;;   return-value method-name(args)
-;; 	   ;; to the form
-;; 	   ;;   method-name(args) : return-value
-;; 	   (mapcar
-;; 	    (lambda (completion)
-;; 	      (let ((completion-short (nth 0 completion))
-;; 		    (completion-long (nth 1 completion)))
-;; 		(if completion-long
-;; 		    (let ((chop-pos (string-match " " completion-long)))
-;; 		      (concat 
-;; 		       (substring completion-long (1+ chop-pos)
-;; 				  (length completion-long)) 
-;; 		       " : " 
-;; 		       (substring completion-long 0 chop-pos)))
-;; 		  completion-short)))
-;; 	    completion-list)
-;; 	   'string<))
-;; 	 (menu	
-;; 	  (cons
-;; 	   "Completions"
-;; 	   (mapcar
-;; 	    (lambda (item)
-;; 	      (vector item (list 'jde-complete-insert-completion item)))
-;; 	    items))))
-;;     (popup-menu-and-execute-in-window menu (selected-window))))
 
 (defun jde-complete-find-all-completions (pat lst &optional exact-match)
   (let ((result nil))
@@ -752,13 +746,31 @@ use `imenu--mouse-menu' to handle the popup menu."
                       ;; if only one item match, return it 
                       (car index-alist)
                     ;; delegates menu handling to imenu :-)
-                    (imenu--mouse-menu index-alist
-                                       (if jde-xemacsp
-                                           nil
-                                         t) ; popup the menu at mouse position
+                    (imenu--mouse-menu index-alist   
+				       (jde-cursor-posn-as-event) ; Popup window at text cursor
                                        (or title "Completion"))))))
     (jde-complete-insert-completion name)))
 
+(defun jde-cursor-posn-as-event()
+  "Returns the text cursor position as an EVENT on Emacs and the
+mouse cursor position on XEmacs."
+  (if jde-xemacsp
+      (let* ((mouse-pos (mouse-pixel-position))
+	     (x (car (cdr mouse-pos)))
+	     (y (cdr (cdr mouse-pos))))
+	(make-event 'button-press `(button 1 modifiers nil x ,x y ,y)))
+    (let ((x (* (if jde-xemacsp (frame-width) (frame-char-width))
+		(if (and
+		     (boundp 'hscroll-mode)
+		     hscroll-mode)
+		    (hscroll-window-column)
+		  (mod (current-column) (window-width)))))
+	  (y  (* (if jde-xemacsp (frame-height) (frame-char-height)) 
+		 (- (count-lines (point-min) (point))
+		  (count-lines (point-min) (window-start)))))
+	  (window (get-buffer-window (current-buffer))))
+      (list (list x y) window))))
+  
 (defun jde-complete-at-point-menu ()
   "Completes the method or field name at point.
 This command displays a popup menu listing the potential completions for the name
@@ -790,8 +802,14 @@ command that lets you cycle throught the potential completions at point."
 (provide 'jde-complete)
 
 ;; $Log: jde-complete.el,v $
-;; Revision 1.2  2001/02/12 05:38:24  paulk
-;; JDE 2.2.7
+;; Revision 1.3  2001/08/16 03:29:15  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.23  2001/04/02 02:45:04  paulk
+;; Add some comments.
+;;
+;; Revision 1.22  2001/03/15 19:47:07  paulk
+;; Now pops up the completion menu at the text cursor position on Emacs and at the mouse cursor position on XEmacs. I will change this to popup at the text cursor position on XEmacs as well as soon as I can figure out how to do it. Thanks to Matt_Conway@i2.com for providing the Emacs version of this enhancement.
 ;;
 ;; Revision 1.21  2001/01/25 04:31:01  paulk
 ;; Completion now asks user whether to import a class that it cannot find. Thanks to Phillip Lord.
