@@ -1,5 +1,5 @@
 ;;; jde-db.el -- Debugger mode for jdb.
-;; $Revision: 1.3 $ $Date: 2001/02/12 05:38:24 $ 
+;; $Revision: 1.4 $ $Date: 2001/08/16 03:29:15 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -322,15 +322,23 @@ Run Option panel variables."
     ;; Set the classpath option. Use the local
     ;; classpath, if set; otherwise, the global
     ;; classpath.
-    (setq options
-	  (nconc
-	   options
-	   (list
-	    "-classpath"
-	   (jde-build-classpath
-	    (if jde-db-option-classpath
-		jde-db-option-classpath
-	      jde-global-classpath)))))
+    (let ((classpath
+	   (if jde-db-option-classpath
+		 jde-db-option-classpath
+	       jde-global-classpath))
+	  (symbol
+	   (if jde-db-option-classpath
+		 'jde-db-option-classpath
+	       'jde-global-classpath)))
+      (if classpath
+	  (setq options
+		(nconc
+		 options
+		 (list
+		  "-classpath"
+		  (jde-build-classpath
+		   classpath symbol))))))
+
 
     ;; Set the verbose options.
     (let ((print-classes-loaded
@@ -534,10 +542,26 @@ breakpoint message."
   ;; on Solaris at debugger startup.
   (if (string-match "running ...\n" jde-db-marker-acc)
       (setq jde-db-marker-acc
-	    (concat "running ...\n"
-		    (substring jde-db-marker-acc 0 (match-beginning 0))
-		    (substring jde-db-marker-acc (match-end 0)))))
-		    
+            (concat "running ...\n"
+                    (substring jde-db-marker-acc 0 (match-beginning 0))
+                    (substring jde-db-marker-acc (match-end 0)))))
+
+
+  ;; This is a hack to fix reordering of message chunks on Windows 2000
+  ;; The problem is the debugger prompt - the thread name with the stack
+  ;; depth (eg main[1]) - sometimes shows up in the middle of the output
+  ;; from the command sent to the debugger.
+  ;; This seems to show up most often with step commands.
+  ;; (message "checking string %s" jde-db-marker-acc)
+  (if (string-match "^.*: \\([-a-zA-Z0-9_$]+\\[[0-9]+\\] \\)thread=" 
+                    jde-db-marker-acc)
+      (setq jde-db-marker-acc
+            (concat (match-string 1 jde-db-marker-acc)
+                    (substring jde-db-marker-acc 0 (match-beginning 1))
+                    (substring jde-db-marker-acc (match-end 1)))))
+  ;; (message "fixed string is %s" jde-db-marker-acc)
+
+
   (let* ((output "")
 	 (oldjdbp (if (string= (car jde-db-debugger) "oldjdb") t))
 	 (marker-regexp 
@@ -691,7 +715,8 @@ breakpoint message."
 	  (n 0))
       (while (< n len)
 	(let ((curr-dir 
-	       (substitute-in-file-name (elt jde-db-source-directories n))))
+	       (jde-normalize-path (elt jde-db-source-directories n)
+				   'jde-db-source-directories)))
 	  (cond
 	   ((jde-db-contains-file-p curr-dir file)
 	    (throw 'found curr-dir))
@@ -745,29 +770,34 @@ and create such a submap in that new map."
 			   "See jde-db-source-directories.") f)
 	  (if jde-xemacsp (window-buffer) nil))))
 
-(defun jde-find-class-source (class)
+(defun jde-find-class-source-file (class)
   "*Find the source file for a specified class.
 CLASS is the fully qualified name of the class. This
 function searchs the source file paths specified by 
 `jde-db-source-directories' for the source file 
 corresponding to CLASS. If it finds the source file,
-it opens the file in a buffer."
-  (interactive "sClass: ")
+it returns the file's path. Otherwise, it returns nil."
   (string-match "^\\(\\(\\(\\w\\|[_]\\)*[.]\\)*\\)\\(\\(\\w\\|[_]\\)+$\\)" class)  
   (let* ((package-name
 	  (substring class (match-beginning 1) (match-end 1)))
 	 (class-name
 	  (substring class (match-beginning 4) (match-end 4)))
 	 (file-name (concat class-name ".java"))
-	 (source-dir
-	  (jde-db-search-src-dirs
-	   file-name
-	   package-name)))
-    (if source-dir
-	(find-file (concat source-dir file-name))
-      (message (concat "JDE error: Could not find source for %s. "
-		       "See `jde-db-source-directories' for more information." )
-		       class))))
+	 (source-dir (jde-db-search-src-dirs file-name package-name)))
+     (if source-dir
+         (expand-file-name file-name source-dir)
+       (message "JDE error: Could not find source for %s. See `jde-db-source-directories' for more information." class)
+       nil)))
+
+(defun jde-find-class-source (class)
+   "*Find the source file for a specified class.
+Calls `jde-find-class-source-file' to do the search.
+If it finds the source file, it opens the file in a buffer."
+   (interactive "sClass: ")
+   (let ((source (jde-find-class-source-file class)))
+     (when source
+       (find-file source))))
+
 
 (defvar jde-db-minibuffer-local-map nil
   "Keymap for minibuffer prompting of jdb startup command.")
@@ -901,7 +931,7 @@ we're in the jdb buffer)."
 	(source-directory default-directory)
 	(working-directory (if (string= jde-run-working-directory "")
 			       default-directory
-			     jde-run-working-directory)))
+			     (jde-normalize-path 'jde-run-working-directory))))
     (if (not (comint-check-proc debug-buf-name))
 	(let* ((debug-buffer (get-buffer-create debug-buf-name))
 	       (debugger (car jde-db-debugger))
@@ -967,7 +997,7 @@ we're in the jdb buffer)."
 buffer."
   (save-excursion
     (goto-char (point-min))
-    (if (re-search-forward "^[ \t]*\\<\\(package\\) *\\([^ \t\n]*\\) *;" (point-max) t)
+    (if (re-search-forward "^[ \t]*\\<\\(package\\) +\\([^ \t\n]*\\) *;" (point-max) t)
 	(concat (buffer-substring-no-properties (match-beginning 2) (match-end 2))
 		"."))))
 
@@ -1162,8 +1192,29 @@ file in the current buffer."
 
 ;; Change History
 ;; $Log: jde-db.el,v $
-;; Revision 1.3  2001/02/12 05:38:24  paulk
-;; JDE 2.2.7
+;; Revision 1.4  2001/08/16 03:29:15  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.76  2001/04/16 05:49:34  paulk
+;; Normalized paths. Thanks to Nick Sieger.
+;;
+;; Revision 1.75  2001/04/12 04:42:23  paulk
+;; Normalize jde-run-working-directory.
+;;
+;; Revision 1.74  2001/04/11 03:21:33  paulk
+;; Updated to resolve relative paths relative to the project file that defines them. Thanks to Nick Sieger.
+;;
+;; Revision 1.73  2001/04/08 04:14:29  paulk
+;; jdb interface has been fixed to work around JDK 1.3 bug that causes the jdb command prompt to sometimes appear in the wrong place in jdb output. Thanks to Andy Bennett <andrew.bennett@ericsson.com> for this fix.
+;;
+;; Revision 1.72  2001/03/16 04:07:03  paulk
+;; Fixed regular expression for finding package in source buffer so that there must be a space between package and the package name. This is to prevent false hits. Thanks to Rory Molinari <molinari@math.lsa.umich.edu>.
+;;
+;; Revision 1.71  2001/03/13 04:14:54  paulk
+;; Split jde-find-class-source into to files, one of which returns the path of the source file while the other opens the file in a buffer.
+;;
+;; Revision 1.70  2001/02/26 04:17:50  paulk
+;; jde-db now handles case where jde-global-classpath and jde-db-option-classpath are nil.
 ;;
 ;; Revision 1.69  2001/02/03 08:44:56  paulk
 ;; Changed declaration of customized variables to allow path completion.
