@@ -1,11 +1,11 @@
 ;;; jde-dbo.el -- JDEbug output functions
-;; $Revision: 1.2 $ $Date: 2001/02/12 05:38:24 $ 
+;; $Revision: 1.3 $ $Date: 2001/08/16 03:29:15 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
 ;; Keywords: java, tools
 
-;; Copyright (C) 1997, 1998, 1999 Paul Kinnucan.
+;; Copyright (C) 1997, 1998, 1999, 2001 Paul Kinnucan.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -37,6 +37,8 @@
 ;;; Code:
 
 (require 'eieio)
+(require 'tree-widget)
+(require 'jde-widgets)
 
 (defclass jde-dbo-thread ()
   ((id      :initarg :id)
@@ -132,8 +134,8 @@ of optional error data."
 (defun jde-dbo-command-result-data (result)
   (nth 2 result))
 
-(defun jde-dbo-report-ids-in-use (id)
-)
+(defun jde-dbo-report-ids-in-use (id-count)
+  (message "%d object ids in use." id-count))
 
 (defun jde-dbo-init-debug-session ()
   (oset jde-dbs-the-debugger started-p t))
@@ -246,20 +248,20 @@ exception spec."
 				   :process process
 				   :object-id (oref var-value id)))
 		       (str-val (jde-dbs-cmd-exec cmd)))
-		  (widget-create 'jde-widget-tree :tag var-tag :value t
-				 (list 'jde-widget-tree :tag str-val)))
+		  (widget-create 'tree-widget :tag var-tag :value t
+				 (list 'tree-widget :tag str-val)))
 	      (widget-create 'jde-widget-java-obj :tag var-tag
 			     :process process :object-id (oref var-value :id))))
 	   ((typep var-value 'jde-dbs-java-array)
 	    (widget-create 'jde-widget-java-array :tag var-tag
 			   :process process :object var-value))
 	   ((typep var-value 'jde-dbs-java-primitive)
-	    (widget-create 'jde-widget-tree :tag var-tag :value t
-			   (list 'jde-widget-tree 
+	    (widget-create 'tree-widget :tag var-tag :value t
+			   (list 'tree-widget 
 				 :tag (format "%s" (oref var-value value)))))
 	   ((typep var-value 'jde-dbs-java-null)
-	    (widget-create 'jde-widget-tree :tag var-tag :value t
-			   (list 'jde-widget-tree :tag "null")))
+	    (widget-create 'tree-widget :tag var-tag :value t
+			   (list 'tree-widget :tag "null")))
 	   (t
 	    (error "Unidentified type of local variable: %s" var-tag)))))
       (use-local-map widget-keymap)
@@ -450,44 +452,66 @@ exception spec."
 	     method-sig))))
 
 (defun jde-dbo-watchpoint-hit-event (process-id process-status thread-spec request-id &rest data)
-  (let* ((thread (jde-dbo-make-thread-obj thread-spec))
+  (let ((process (jde-dbs-get-process process-id)))
+    (if process
+	(let* ((thread (jde-dbo-make-thread-obj thread-spec))
+	       (thread-id (oref thread id))
+	       (thread-name (oref thread name))
+	       (thread-state (oref thread state))
+	       (thread-status (oref thread status))
 	 
-	 ;; Object whose field was accessed or modified.
-	 (obj-spec (nth 0 data))
-	 (obj-class (nth 0 obj-spec))
-	 (obj-id (nth 1 obj-spec))
-	 (obj-gc-flag  (nth 2 obj-spec))
-	 ;; Field that was accessed or modified.
-	 (field-spec (nth 1 data))
-	 (field-decl (nth 0 field-spec))
-	 (field-name (nth 0 field-decl))
-	 (field-type (nth 1 field-decl))
-	 (field-qual (if (> (length field-decl) 3) (nth 2 field-decl)))
-	 (field-value-type (nth 1 field-spec))
-	 (field-value (nth 2 field-spec))
-	 ;; Breakpoint data
-	 (breakpoint-spec (nth 2 data))
-	 (breakpoint-class (nth 0 breakpoint-spec))
-	 (breakpoint-file (nth 1 breakpoint-spec))
-	 (breakpoint-line (nth 2 breakpoint-spec))
-	 ;; Object match data
-	 (obj-match (nth 3 data))
-	 ;; Thread match data
-	 (thread-match (nth 4 data))
-	 ;; Expression true data
-	 (expression-true (nth 5 data))
-	 (process (jde-dbs-get-process process-id))
-	 )
+	       ;; Object whose field was accessed or modified.
+	       (obj-spec (nth 0 data))
+	       (obj-class (nth 0 obj-spec))
+	       (obj-id (nth 1 obj-spec))
+	       (obj-gc-flag  (nth 2 obj-spec))
+	       ;; Field that was accessed or modified.
+	       (field-spec (nth 1 data))
+	       (field-decl (nth 0 field-spec))
+	       (field-name (nth 0 field-decl))
+	       (field-type (nth 1 field-decl))
+	       (field-qual (if (> (length field-decl) 3) (nth 2 field-decl)))
+	       (field-value-type (nth 1 field-spec))
+	       (field-value (nth 2 field-spec))
+	       ;; Breakpoint data
+	       (breakpoint-spec (nth 2 data))
+	       (breakpoint-class (nth 0 breakpoint-spec))
+	       (breakpoint-file (nth 1 breakpoint-spec))
+	       (breakpoint-line (nth 2 breakpoint-spec))
+	       ;; Object match data
+	       (obj-match (nth 3 data))
+	       ;; Thread match data
+	       (thread-match (nth 4 data))
+	       ;; Expression true data
+	       (expression-true (nth 5 data)))
 
-    (if (string= (oref thread status) "suspended by debugger")
-	(jde-dbo-show-line breakpoint-class breakpoint-file breakpoint-line))
+	  (jde-dbs-proc-display-debug-message 
+	   process
+	   (format "<%s:%s> accessed or modified at line %s in %s.\n  Watched field: %s %s %s = %s\n" 
+		   obj-class obj-id breakpoint-line breakpoint-file 
+		   (if field-qual field-qual "") field-type field-name field-value))
 
-    (jde-dbs-proc-display-debug-message 
-     process
-     (format "<%s:%s> accessed or modified at line %s in %s.\n  Watched field: %s %s %s = %s\n" 
-	     obj-class obj-id breakpoint-line breakpoint-file 
-	     (if field-qual field-qual "") field-type field-name field-value))
-  ))         
+	  (if (string= thread-status "suspended by debugger")
+	      (let ((state-info (oref process state-info)))
+		(if state-info
+		    (progn
+		      (jde-dbs-proc-state-info-set 
+		       state-info thread-state 
+		       thread-status thread-id thread-name)
+		      (jde-dbo-update-locals-buf process thread-id 0)
+		      (jde-dbo-update-stack process thread-id)
+		      (oset process steppablep t)
+		      (jde-dbo-show-line breakpoint-class breakpoint-file breakpoint-line)
+		      (when jde-bug-raise-frame-p (raise-frame))
+
+		      (jde-dbs-display-debug-message 
+		       process-id
+		       (format "Stopping at line %d in %s (%s) on thread %s." 
+			       breakpoint-line breakpoint-class breakpoint-file thread-name)))
+		  (message "Watchpoint event error: state info object missing for process %d." 
+			   process-id)))))
+      (message "Watchpoint event error: process object for process %d is missing." process-id))))
+	    
 
 (defun jde-dbo-event-set (process-id process-status thread &rest events)
   "Invoked when a set of debugger events occurs. EVENTS is a list of
