@@ -1,12 +1,12 @@
 ;;; jde-imenu.el --- imenu setup for the JDE
-;; $Revision: 1.1 $ 
+;; $Revision: 1.2 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>,
 ;;         David Ponce <david@dponce.com>
 ;; Maintainer: Paul Kinnucan, David Ponce
 ;; Keywords: java, tools
 
-;; Copyright (C) 2000 Paul Kinnucan.
+;; Copyright (C) 2000, 2001 Paul Kinnucan.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -27,12 +27,28 @@
 
 ;;; Code:
 
+(require 'semantic-java)
 (require 'semantic-imenu)
-(require 'semantic-mode)
 
-;;;
-;;; Global options
-;;;
+;;; Compatibility
+(cond
+ ((fboundp 'char-valid-p)
+  (defalias 'jde-imenu-char-valid-p 'char-valid-p))
+ ((fboundp 'char-int-p)
+  (defalias 'jde-imenu-char-valid-p 'char-int-p))
+ (t
+  (defun jde-imenu-char-valid-p (object)
+    "Return t if OBJECT is a valid normal character."
+    (condition-case nil
+        (progn
+          (char-to-string object)
+          t)
+      (error nil))))
+ )
+
+;;;;
+;;;; Global options
+;;;;
 
 (defcustom jde-imenu-enable t
   "*Enables creation of a classes index menu in the Emacs menubar."
@@ -79,7 +95,10 @@ See also `jde-imenu-modifier-abbrev-alist'."
   "Default value of `jde-imenu-modifier-abbrev-alist'.")
 
 (defconst jde-imenu-valid-modifiers-regexp
-  "\\b\\(public\\|protected\\|private\\|static\\|abstract\\|final\\|native\\|synchronized\\|transient\\|volatile\\|strictfp\\)\\b"
+  (concat "\\b"
+          (regexp-opt
+           (mapcar #'car jde-imenu-default-modifier-abbrev-alist) t)
+          "\\b")
   "Regexp of valid Java modifiers used by
 `jde-imenu-modifier-field-validate'.")
 
@@ -99,9 +118,10 @@ Used by `jde-imenu-modifier-abbrev-alist' customization."
  Used by `jde-imenu-modifier-abbrev-alist' customization."
   (save-excursion
     (let ((value (widget-value widget)))
-      (if (char-valid-p value)
+      (if (jde-imenu-char-valid-p value)
           nil
-        (widget-put widget :error (format "Invalid character value: %S" value))
+        (widget-put widget :error
+                    (format "Invalid character value: %S" value))
         widget))))
       
 (defcustom jde-imenu-modifier-abbrev-alist
@@ -153,12 +173,12 @@ Use *Rescan* to rebuild the imenu when you have changed this option."
                        nil)))
           ;; global
           (set-default 'semantic-imenu-sort-bucket-function
-                              semantic-imenu-sort-bucket-function)
+                       semantic-imenu-sort-bucket-function)
           (set-default sym val)))
 
-;;;
-;;; Helper functions
-;;;
+;;;;
+;;;; Helper functions
+;;;;
 
 (defun jde-imenu-abbreviate-modifiers (modifiers)
   "Return a string of character abbreviations for MODIFIERS or \"\" if
@@ -175,85 +195,65 @@ also `jde-imenu-include-modifiers')."
               alist (cdr alist))
         (if (member (car entry) modifiers)
             (setq abbrevs
-                  (concat abbrevs (if (char-valid-p (cdr entry))
+                  (concat abbrevs (if (jde-imenu-char-valid-p (cdr entry))
                                       (char-to-string (cdr entry))
                                     "")))))
       (if (> (length abbrevs) 0)
-          (concat abbrevs " ")          ; trailing whitespace separator
+          (concat abbrevs " ")         ; trailing whitespace separator
         abbrevs))))
 
-;;;
-;;; Universal `semantic-imenu' stuff adapted to JDE's needs
-;;;
+;;;;
+;;;; Universal `semantic-imenu' stuff adapted to JDE's needs
+;;;;
 
-(defun jde-imenu-prototype-nonterminal (token)
+(defun jde-imenu-prototype-nonterminal (token &optional parent color)
   "Return a prototype for TOKEN.
 See also `semantic-prototype-nonterminal'."
   (let* ((token-cat  (semantic-token-token token))
-         (token-name (semantic-token-name  token))
-         (prototyper (intern (concat "jde-imenu-prototype-"
-                                     (symbol-name token-cat)))))
+         (prototyper (intern-soft (format "jde-imenu-prototype-%s"
+                                          token-cat))))
     (if (fboundp prototyper)
-        (funcall prototyper token)
-      (message "Unknow token %S" token-cat))))
+        (funcall prototyper token parent color)
+      (semantic-java-prototype-nonterminal token parent color))))
 
-(defun jde-imenu-prototype-function (token)
+(defun jde-imenu-prototype-function (token &optional parent color)
   "Return a function (method) prototype for TOKEN.
-See also `semantic-prototype-nonterminal'."
-  (let ((name (semantic-token-name  token))
-        (mods (semantic-token-function-modifiers token))
-        sign)
-    (if jde-imenu-include-signature
-        (let ((type (semantic-token-type token))
-              (args (semantic-token-function-args token)))
-          (setq sign (if type
-                        (format "%s %s(" type name)
-                      (format "%s(" name)))
-          (while args
-            (let ((arg-token (car args))
-                  arg-type)
-              (when (semantic-token-p arg-token)
-                (setq arg-type (semantic-token-type arg-token))
-                (setq sign (concat sign arg-type ",")))
-              (setq args (cdr args))))
-          ;; remove the extra comma at end
-          (if (char-equal ?, (aref sign (1- (length sign))))
-              (setq sign (substring sign 0 -1)))
-          (setq sign (concat sign ")")))
-      (setq sign (format "%s()" name)))
-    (format "%s%s" (jde-imenu-abbreviate-modifiers mods) sign)))
+See also `semantic-java-prototype-function'."
+  (let ((sign (if jde-imenu-include-signature
+                  (semantic-java-prototype-function token parent color)
+                (concat (if color
+                            (semantic-colorize-text
+                             (semantic-token-name token) 'function)
+                          (semantic-token-name token))
+                        "()"))))
+    (concat (jde-imenu-abbreviate-modifiers
+             (semantic-token-function-modifiers token))
+            sign)))
 
-(defun jde-imenu-prototype-variable (token)
+(defun jde-imenu-prototype-variable (token &optional parent color)
   "Return a variable (field) prototype for TOKEN.
-See also `semantic-prototype-nonterminal'."
-  (let ((name (semantic-token-name token))
-        (mods (semantic-token-variable-modifiers token)))
-    (if jde-imenu-include-signature
-        (setq name (concat (semantic-token-type token)
-                           " " name)))
-    (format "%s%s" (jde-imenu-abbreviate-modifiers mods) name)))
+See also `semantic-java-prototype-variable'."
+  (let ((sign (if jde-imenu-include-signature
+                  (semantic-java-prototype-variable token parent color)
+                (if color
+                    (semantic-colorize-text
+                     (semantic-token-name token) 'variable)
+                  (semantic-token-name token)))))
+    (concat (jde-imenu-abbreviate-modifiers
+             (semantic-token-variable-modifiers token))
+            sign)))
 
-(defun jde-imenu-prototype-type (token)
+(defun jde-imenu-prototype-type (token &optional parent color)
   "Return a type (class/interface) prototype for TOKEN.
 See also `semantic-prototype-nonterminal'."
-  (let ((name  (semantic-token-name token))
-        (type  (semantic-token-type token))
-        (mods  (semantic-token-type-modifiers token)))
-    (format "%s%s %s" (jde-imenu-abbreviate-modifiers mods) type name)))
+  (let ((sign (semantic-java-prototype-type token parent color)))
+    (concat (jde-imenu-abbreviate-modifiers
+             (semantic-token-type-modifiers token))
+            sign)))
 
-(defun jde-imenu-prototype-include (token)
-  "Return an include (import) prototype for TOKEN.
-See also `semantic-prototype-nonterminal'."
-  (semantic-token-name token))
-
-(defun jde-imenu-prototype-package (token)
-  "Return a package prototype for TOKEN.
-See also `semantic-prototype-nonterminal'."
-  (semantic-token-name token))
-
-;;;
-;;; Specific JDE's imenu (to be replaced by semantic-imenu stuff)
-;;;
+;;;;
+;;;; Specific JDE's imenu (to be replaced by semantic-imenu stuff)
+;;;;
 
 (defcustom jde-imenu-include-classdef t
   "*If non-nil `jde-imenu-index-class' adds *class def* items in imenu
@@ -406,29 +406,17 @@ This function uses the semantic bovinator to index the buffer."
 	(setq packages (cdr packages)))
       index))
 
-;;;
-;;; JDE's imenu setup
-;;;
+;;;;
+;;;; JDE's imenu setup
+;;;;
 
 (defun jde-imenu-setup ()
   "Setup the JDE's \"Classes\" imenu when entering jde-mode."
   (when jde-imenu-enable
 
-    ;; function to use when creating items in imenu.
-    (setq semantic-imenu-summary-function
-          'semantic-prototype-nonterminal)
-
-    ;; speedbar and imenu buckets name.
-    (setq semantic-symbol->name-assoc-list
-          '((type     . "Classes")
-            (variable . "Variables")
-            (function . "Methods")
-            (include  . "Imports")
-            (package  . "Package")))
-
     ;; semantic overloaded functions
-    (setq semantic-override-table
-          '((prototype-nonterminal . jde-imenu-prototype-nonterminal)))
+    (semantic-install-function-overrides
+     '((prototype-nonterminal . jde-imenu-prototype-nonterminal)))
 
     ;; function to use for creating the imenu
     (setq imenu-create-index-function
@@ -439,20 +427,19 @@ This function uses the semantic bovinator to index the buffer."
     ;; add the imenu to the menu bar for the current buffer
     (imenu-add-to-menubar "Classes")
 
-    ;; enable `semantic-minor-mode', so imenu configuration and others
-    ;; semantic services will be available in the "Parse" menu.
-    ;; (semantic-minor-mode 1)
     ))
 
-;; Enable which-function-mode in jde-mode (using semantic parser)
-(eval-after-load "which-func"
-  '(add-to-list 'which-func-modes 'jde-mode))
-
 (provide 'jde-imenu)
 
 ;; $Log: jde-imenu.el,v $
-;; Revision 1.1  2001/02/12 05:40:58  paulk
-;; Initial XEmacs version.
+;; Revision 1.2  2001/08/16 03:29:18  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.4  2001/05/23 03:51:45  paulk
+;; Removed which-func support as jde-which-method is better.
+;;
+;; Revision 1.3  2001/05/19 02:35:59  paulk
+;; Updated to support semantic 1.4. Thanks to David Ponce.
 ;;
 ;; Revision 1.2  2000/11/27 06:18:39  paulk
 ;; Miscellaneous bug fixes and minor enhancements.
