@@ -1,15 +1,15 @@
-;;; jde-import-org.el --- Organize Java imports
+;;; jde-import.el --- Organize Java imports
 
-;; Copyright (C) 2000 by David Ponce
+;; Copyright (C) 2000, 2001 by David Ponce
 
 ;; Authors:     David Ponce <david@dponce.com>
 ;;              Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainers: David Ponce <david@dponce.com>
 ;;              Paul Kinnucan <paulk@mathworks.com>
 ;; Created: 15 Nov 2000
-;; Version: $Revision: 1.1 $
+;; Version: $Revision: 1.2 $
 ;; Keywords: java, tools
-;; VC: $Id: jde-import.el,v 1.1 2001/02/12 05:42:50 paulk Exp $
+;; VC: $Id: jde-import.el,v 1.2 2001/08/16 03:29:19 andyp Exp $
 
 ;; This file is not part of Emacs
 
@@ -36,8 +36,21 @@
 ;;; History:
 ;;
 ;; $Log: jde-import.el,v $
-;; Revision 1.1  2001/02/12 05:42:50  paulk
-;; Initial XEmacs revision.
+;; Revision 1.2  2001/08/16 03:29:19  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.5  2001/04/27 01:33:42  paulk
+;; jde-import-sort now refreshes parse cache. Thanks to Robert Mecklenburg <mecklen@cimsoft.com> for tthis fix.
+;;
+;; Revision 1.4  2001/04/26 09:06:07  paulk
+;; -- jde-import-kill-extra-imports now refreshes the buffer's parse cache. This fixes a bug where successive calls to the function would incorrectly remove imports.
+;;
+;; -- jde-import-kill-extra-imports now removes fully qualified imports that are not referenced in the code.
+;;
+;; Thanks to "Javier Lopez" <jlopez@cellexchange.com>.
+;;
+;; Revision 1.3  2001/03/13 04:19:45  paulk
+;; Cosmetic changes.
 ;;
 ;; Revision 1.2  2000/11/27 06:18:40  paulk
 ;; Miscellaneous bug fixes and minor enhancements.
@@ -211,7 +224,7 @@ semantic Java parser and requires JDE 2.1.6-beta24 and above."
   (and (interactive-p)
        (consp current-prefix-arg)
        (setq reverse t))
-  (let* ((tokens  (semantic-bovinate-toplevel))
+  (let* ((tokens  (semantic-bovinate-toplevel t))
          (depends (semantic-find-nonterminal-by-token 'include tokens)))
     (if depends
         (let* ((first-import-token (car depends))
@@ -313,7 +326,7 @@ rt.jar."
       (setq i 0)
       (setq n (length new-imports))
       (while (< i n)
-	(let (deactivate-mark) t)
+	(if (not jde-xemacsp) (deactivate-mark))
 	(let ((new-import 
 	       (nth i new-imports)))
 	  (progn
@@ -452,7 +465,7 @@ The current buffer must be in `jde-mode'."
   (and (interactive-p)
        (consp current-prefix-arg)
        (setq comment t))
-  (let* ((tokens   (semantic-bovinate-toplevel))
+  (let* ((tokens   (semantic-bovinate-toplevel t))
          (imports  (semantic-find-nonterminal-by-token 'include tokens)))
     (if (not imports)
         (message "No import found")
@@ -477,14 +490,24 @@ The current buffer must be in `jde-mode'."
 	     (first-import (car imports))
 	     extra-imports 
 	     required-imports)
-      ;; Get the list of extra imports
+	;; Get the list of extra imports
+	;; Going to character zero so the the count-matches method work.
+	(goto-char 0)
       (while imports
 	(let* ((import (car imports))
-	       (name (semantic-token-name import)))
+	       (name (semantic-token-name import))
+	       (classname (jde-import-get-classname name))
+	       (number-of-matches (substring (count-matches classname) 0 2)))
+	  (prin1 classname)
+	  (prin1 number-of-matches)
 	  (if (or 
 	       ;; If name is already listed in the set
-               ;; of required imports...
+	       ;; of required imports...
 	       (member name required-imports)
+	       ;;or the class is not reference in the file
+	       ;;and is not an import of the whole package i.e. .*
+	       (and (< (string-to-number number-of-matches) 2)
+		    (not (string= classname "*")))
 	       ;; or imports a class in the current package...
 	       (and
 		;; make sure name is not a package import, e.g., foo.bar.*
@@ -505,7 +528,7 @@ The current buffer must be in `jde-mode'."
 	    (setq required-imports (cons name required-imports))))
 	(setq imports (cdr imports)))
       (if (not extra-imports)
-          (message "No extra imports found")
+	  (message "No extra imports found")
 	(let ((count 0))
 	  ;; Move the point at the beginning of the first import
 	  (goto-char (semantic-token-start first-import))
@@ -528,12 +551,24 @@ The current buffer must be in `jde-mode'."
 			       (point))))
 	      (setq extra-imports (cdr extra-imports))))
 	  (message "%d extra import%s removed"
-                 count (if (= count 1) "" "s")))))))))
+                count (if (= count 1) "" "s")))))))))
 
 ;;;;
 ;;;; Helper functions
 ;;;;
 
+(defun jde-import-get-classname(import)
+  "Takes as an argument an import i.e. java.util.Vector.
+And returns the class name. In the above example it will
+return Vector"
+  (let ((pieces (split-string import "\\.")))
+    (while pieces 
+      (let* ((current (car pieces)))
+	(setq pieces (cdr pieces))
+	(if (not (string= nil current))
+	    (setq class current))))
+    class))
+
 (defun jde-import-group-of (import-token)
   "Return the group IMPORT-TOKEN belongs to or nil if not found.
 A group is found as soon as the import name matches a regexp in
