@@ -7,7 +7,7 @@
 ;;             Paul Kinnucan <paulk@mathworks.com>
 ;; Created: September 28 1998
 ;; Keywords: java, tools
-;; VC: $Id: jde-java-font-lock.el,v 1.1 2001/02/12 05:45:05 paulk Exp $
+;; VC: $Id: jde-java-font-lock.el,v 1.2 2001/08/16 03:29:19 andyp Exp $
 
 ;; This file is not part of Emacs
 
@@ -30,61 +30,73 @@
 ;;
 ;; Adds some extra level font locking for java in `jde-mode'.
 ;;
-;; * Numbers are fontified with `jde-java-font-lock-number-face'.
+;; - Numbers are fontified with `jde-java-font-lock-number-face'.
 ;;
-;; * Modifiers are fontified with `font-lock-builtin-face'.  This face
-;;   is based on XEmacs `font-lock-preprocessor-face' if available.
+;; - Packages in package and import statements are fontified with
+;;   `jde-java-font-lock-package-face'.  Last '*' of imported packages
+;;   are fontified with `jde-java-font-lock-number-face'.  Last type
+;;   identifiers of imported packages are fontified with
+;;   `font-lock-type-face'.
 ;;
-;; * Keywords const and goto are fontified with
+;; - Modifiers are fontified with `jde-java-font-lock-modifier-face'.
+;;
+;; - Keywords const and goto are fontified with
 ;;   `font-lock-warning-face'.  These keywords are reserved, even
 ;;   though they are not currently used.
 ;;
-;; * The keyword default is fontified with `font-lock-keyword-face'.
+;; - Keywords super, this and default are fontified with
+;;   `font-lock-keyword-face'.
 ;;
-;; * User's defined identifiers (see variable
+;; - User's defined identifiers (see variable
 ;;   `jde-java-font-lock-api-file') are fontified with
 ;;   `jde-java-font-lock-api-face'.
 ;;
-;; * Capitalized identifiers, text between `' in comments and javadoc
-;;   tags (including non official javadoc tags) are fontified with
-;;   `font-lock-constant-face'.  This face is based on XEmacs
-;;   `font-lock-reference-face' if available.
+;; - Capitalized identifiers and special constants null, true and
+;;   false are fontified with `jde-java-font-lock-constant-face'.
 ;;
-;; * Javadoc links (following @link tags or enclosed in HTML <a> tags)
+;; - Text between `' in comments and javadoc tags (including non
+;;   official javadoc tags) are fontified with
+;;   `jde-java-font-lock-doc-tag-face'.
+;;
+;; - Javadoc links (following @link tags or enclosed in HTML <a> tags)
 ;;   are fontified with `jde-java-font-lock-link-face'
 ;;
-;; * Javadoc code samples (enclosed in HTML <code> tags or following
-;;   @see tags) are fontified with `jde-java-font-lock-code-face'.  By
-;;   default, this face is based on `font-lock-builtin-face'.
+;; - Javadoc code samples (enclosed in HTML <code> tags or following
+;;   @see tags) are fontified with `jde-java-font-lock-code-face'.
 ;;  
-;; * Javadoc HTML bold style is fontified with
-;;   `jde-java-font-lock-bold-face'.  By default, this face is based
-;;   on `bold'.
+;; - Javadoc HTML bold and strong styles are fontified with
+;;   `jde-java-font-lock-bold-face'.
 ;;
-;; * Javadoc HTML italic style is fontified with
-;;   `jde-java-font-lock-italic-face'.  By default, this face is based
-;;   on `italic'.
+;; - Javadoc HTML italic and emphasized styles are fontified with
+;;   `jde-java-font-lock-italic-face'.
 ;;
-;; * Javadoc HTML underlined style is fontified with
-;;   `jde-java-font-lock-underline-face'.  By default, this face is
-;;   based on `underline'.
+;; - Javadoc HTML underlined style is fontified with
+;;   `jde-java-font-lock-underline-face'.
 ;;
-;; * Javadoc HTML preformatted style is fontified with
-;;   `jde-java-font-lock-pre-face'.  By default, this face is based on
-;;   `default'.
+;; - Javadoc HTML preformatted style is fontified with
+;;   `jde-java-font-lock-pre-face'.
 ;;
 ;; All font-lock and jde-java-font-lock faces are individually
-;; customizable.
+;; customizable.  jde-java-font-lock faces are in the customization
+;; group `jde-java-font-lock-faces' which is a sub group of
+;; `font-lock-highlighting-faces' (Emacs) or `font-lock-faces'
+;; (XEmacs).
 
 ;; This code has been tested with FSF Emacs 20.7, 21.0 and XEmacs
 ;; 21.1.  Any comments, suggestions, bug reports or upgrade requests
 ;; are welcome.  Please send them to the maintainers.
 
+;; WARNING: It seems there is byte-code compatibility issues between
+;; Emacs and XEmacs.  When using Emacs byte-code on XEmacs font
+;; locking don't work correctly for some complex matchers like those
+;; used to highlight imported package name :-)
+
 ;;; History:
 ;;
 ;; See at end of this file.
 
 ;;; Code:
+(require 'font-lock)
 
 (defcustom jde-use-font-lock t
   "*Turn on font-locking if non-nil.
@@ -92,11 +104,27 @@ Set to nil to disable the use of font-locking."
   :group 'jde-project
   :type 'boolean)
 
+(defcustom jde-java-font-lock-max-names-by-regexp
+  (if (featurep 'xemacs) 200 0)
+  "*Maximum number of user defined names that one regexp can match.
+No limit if less than 1.
+
+WARNING: It seems XEmacs search fails with a very long regexp.  So the
+XEmacs default limits is 200.  No limit for Emacs."
+  :group 'jde-project
+  :type 'integer)
+
 ;;;;
 ;;;; Define the faces
 ;;;;
 
-;; Create a specific face for numbers
+(defgroup jde-java-font-lock-faces nil
+  "Specific JDE faces for highlighting Java sources."
+  :prefix "jde-java-font-lock-"
+  :group (if (featurep 'xemacs)
+             'font-lock-faces
+           'font-lock-highlighting-faces))
+
 (defface jde-java-font-lock-number-face
   '((((class grayscale) (background light)) (:foreground "DimGray" :italic t))
     (((class grayscale) (background dark)) (:foreground "LightGray" :italic t))
@@ -104,73 +132,95 @@ Set to nil to disable the use of font-locking."
     (((class color) (background dark)) (:foreground "LightSalmon"))
     (t (:italic t)))
   "Font Lock mode face used to highlight numbers."
-  :group 'font-lock-highlighting-faces)
+  :group 'jde-java-font-lock-faces)
+
+(defface jde-java-font-lock-constant-face
+  '((((type tty) (class color)) (:foreground "magenta"))
+    (((class grayscale) (background light))
+     (:foreground "LightGray" :bold t :underline t))
+    (((class grayscale) (background dark))
+     (:foreground "Gray50" :bold t :underline t))
+    (((class color) (background light)) (:foreground "CadetBlue"))
+    (((class color) (background dark)) (:foreground "Aquamarine"))
+    (t (:bold t :underline t)))
+  "Font Lock mode face used to highlight constants."
+  :group 'jde-java-font-lock-faces)
 
-;; Create a specific face for user's defined names
 (defface jde-java-font-lock-api-face
   '((((class grayscale) (background light)) (:foreground "DimGray"))
     (((class grayscale) (background dark)) (:foreground "LightGray"))
     (((class color) (background light)) (:foreground "dark goldenrod"))
     (((class color) (background dark)) (:foreground "light goldenrod")))
   "Font Lock mode face used to highlight user's defined names."
-  :group 'font-lock-highlighting-faces)
+  :group 'jde-java-font-lock-faces)
 
-;; Create a specific face for links
 (defface jde-java-font-lock-link-face
   '((t (:foreground "blue" :italic nil :underline t)))
   "Font Lock mode face used to highlight links."
-  :group 'font-lock-highlighting-faces)
+  :group 'jde-java-font-lock-faces)
 
-;;; Compatibility
-(if jde-xemacsp
-    (progn
-      
-      (defvar font-lock-builtin-face 'font-lock-builtin-face
-	"Face name to use for builtins.")
+(defface jde-java-font-lock-package-face
+  '((((class color) (background dark)) (:foreground "steelblue1"))
+    (((class color) (background light)) (:foreground "blue3"))
+    (t (:underline t)))
+  "Font Lock Mode face used to highlight packages."
+  :group 'jde-java-font-lock-faces)
 
-      ;; For consistency try to define the builtin face as the XEmacs
-      ;; preprocessor face
-      (condition-case nil
-          (copy-face 'font-lock-preprocessor-face 'font-lock-builtin-face)
-        (error
-         (defface font-lock-builtin-face
-           '((t (:foreground "blue" :italic nil :underline t)))
-           "Font Lock mode face used to highlight builtins."
-           :group 'font-lock-highlighting-faces)))
+(defface jde-java-font-lock-doc-tag-face
+  '((((class color) (background dark)) (:foreground "light coral"))
+    (((class color) (background light)) (:foreground "green4"))
+    (t (:bold t)))
+  "Font Lock Mode face used to highlight doc tags."
+  :group 'jde-java-font-lock-faces)
 
-      (defvar font-lock-constant-face 'font-lock-constant-face
-        "Face name to use for constant and label names.")
-      
-      ;; For consistency try to define the constant face as the XEmacs
-      ;; reference face
-      (condition-case nil
-          (copy-face 'font-lock-reference-face 'font-lock-constant-face)
-        (error
-         (defface font-lock-constant-face
-           '((((class grayscale) (background light))
-              (:foreground "LightGray" :bold t :underline t))
-             (((class grayscale) (background dark))
-              (:foreground "Gray50" :bold t :underline t))
-             (((class color) (background light)) (:foreground "CadetBlue"))
-             (((class color) (background dark)) (:foreground "Aquamarine"))
-             (t (:bold t :underline t)))
-           "Font Lock mode face used to highlight constants and labels."
-           :group 'font-lock-highlighting-faces)))
+(defface jde-java-font-lock-modifier-face
+  '((((type tty) (class color)) (:foreground "blue" :weight light))
+    (((class grayscale) (background light)) (:foreground "LightGray" :bold t))
+    (((class grayscale) (background dark)) (:foreground "DimGray" :bold t))
+    (((class color) (background light)) (:foreground "Orchid"))
+    (((class color) (background dark)) (:foreground "LightSteelBlue"))
+    (t (:bold t)))
+  "Font Lock Mode face used to highlight modifiers."
+  :group 'jde-java-font-lock-faces)
 
-      ))
+(defface jde-java-font-lock-bold-face
+  '((t (:bold t)))
+  "Font Lock Mode face used to highlight HTML bold text style."
+  :group 'jde-java-font-lock-faces)
 
-;; Make new faces based on existing ones
-(copy-face 'bold                   'jde-java-font-lock-bold-face)
-(copy-face 'italic                 'jde-java-font-lock-italic-face)
-(copy-face 'underline              'jde-java-font-lock-underline-face)
-(copy-face 'default                'jde-java-font-lock-pre-face)
-(copy-face 'font-lock-builtin-face 'jde-java-font-lock-code-face)
+(defface jde-java-font-lock-italic-face
+  '((t (:italic t)))
+  "Font Lock Mode face used to highlight HTML italic text style."
+  :group 'jde-java-font-lock-faces)
+
+(defface jde-java-font-lock-underline-face
+  '((t (:underline t)))
+  "Font Lock Mode face used to highlight HTML underlined text style."
+  :group 'jde-java-font-lock-faces)
+
+(defface jde-java-font-lock-pre-face
+  '((t nil))
+  "Font Lock Mode face used to highlight HTML preformatted text style."
+  :group 'jde-java-font-lock-faces)
+
+(defface jde-java-font-lock-code-face
+  '((t nil))
+  "Font Lock Mode face used to highlight HTML program code style."
+  :group 'jde-java-font-lock-faces)
 
 ;; Define the extra font lock faces
 (defvar jde-java-font-lock-number-face    'jde-java-font-lock-number-face
   "Face name to use for numbers.")
+(defvar jde-java-font-lock-constant-face  'jde-java-font-lock-constant-face
+  "Face name to use for constants.")
+(defvar jde-java-font-lock-package-face   'jde-java-font-lock-package-face
+  "Face name to use for packages.")
+(defvar jde-java-font-lock-modifier-face  'jde-java-font-lock-modifier-face
+  "Face name to use for modifiers.")
 (defvar jde-java-font-lock-api-face       'jde-java-font-lock-api-face
   "Face name to use for user's defined names.")
+(defvar jde-java-font-lock-doc-tag-face   'jde-java-font-lock-doc-tag-face
+  "Face name to use for doc tags.")
 (defvar jde-java-font-lock-link-face      'jde-java-font-lock-link-face
   "Face name to use for links.")
 (defvar jde-java-font-lock-bold-face      'jde-java-font-lock-bold-face
@@ -212,7 +262,7 @@ Set to nil to disable the use of font-locking."
 (defun jde-java-font-lock-remove-javadoc-keywords (keywords)
   "Remove existing javadoc font lock keywords from KEYWORDS.
 That is those with \"@\" in their matcher regexp."
-  (let (kw matcher match)
+  (let (kw matcher)
     (while keywords
       (setq matcher  (car keywords)
             keywords (cdr keywords))
@@ -263,9 +313,9 @@ position."
   "Return a font lock keyword for comment enclosed in \`\'."
   `((lambda (end)
       (jde-java-font-lock-search-in-comment
-       "`\\(.*\\)'"
+       "`\\([^']*\\)'"
        end))
-    1 font-lock-constant-face t))
+    1 jde-java-font-lock-doc-tag-face t))
 
 (defun jde-java-font-lock-html-ahref-keyword ()
   "Return a font lock keyword for HTML A HREF anchor.
@@ -276,32 +326,25 @@ Only fontify javadoc comments."
        end))
     1 jde-java-font-lock-link-face t))
 
-(defun jde-java-font-lock-html-strong-keyword ()
-  "Return a font lock keyword for HTML STRONG style.
-Only fontify javadoc comments."
-  `((lambda (end)
-      (jde-java-font-lock-search-in-javadoc
-       "<[Ss][Tt][Rr][Oo][Nn][Gg]>\\([^<]*\\)</[Ss][Tt][Rr][Oo][Nn][Gg]>"
-       end))
-    1 jde-java-font-lock-bold-face t))
-
 (defun jde-java-font-lock-html-bold-keyword ()
-  "Return a font lock keyword for HTML B style.
+  "Return a font lock keyword for HTML B and STRONG style.
 Only fontify javadoc comments."
   `((lambda (end)
       (jde-java-font-lock-search-in-javadoc
-       "<[Bb]>\\([^<]*\\)</[Bb]>"
+       , (concat "<\\([Bb]\\|[Ss][Tt][Rr][Oo][Nn][Gg]\\)>"
+                 "\\([^<]*\\)"
+                 "</\\([Bb]\\|[Ss][Tt][Rr][Oo][Nn][Gg]\\)>")
        end))
-    1 jde-java-font-lock-bold-face t))
+    2 jde-java-font-lock-bold-face t))
 
 (defun jde-java-font-lock-html-italic-keyword ()
-  "Return a font lock keyword for HTML I style.
+  "Return a font lock keyword for HTML I and EM style.
 Only fontify javadoc comments."
   `((lambda (end)
       (jde-java-font-lock-search-in-javadoc
-       "<[Ii]>\\([^<]*\\)</[Ii]>"
+       "<\\([Ii]\\|[Ee][Mm]\\)>\\([^<]*\\)</\\([Ii]\\|[Ee][Mm]\\)>"
        end))
-    1 jde-java-font-lock-italic-face t))
+    2 jde-java-font-lock-italic-face t))
 
 (defun jde-java-font-lock-html-underline-keyword ()
   "Return a font lock keyword for HTML U style.
@@ -338,7 +381,7 @@ Only fontify javadoc comments."
        ,(concat "^[ \t]*\\(/\\*\\*\\|\\*?\\)[ \t]*"
                 "\\(@[" jde-java-font-lock-letter-or-digit "]+\\)")
        end))
-    2 font-lock-constant-face t))
+    2 jde-java-font-lock-doc-tag-face t))
 
 (defun jde-java-font-lock-javadoc-docroot-keyword ()
   "Return a font lock keyword for javadoc @docRoot tags.
@@ -347,7 +390,7 @@ Only fontify javadoc comments."
       (jde-java-font-lock-search-in-javadoc
        "{\\(@docRoot\\)}"
        end))
-    1 font-lock-constant-face t))
+    1 jde-java-font-lock-doc-tag-face t))
 
 (defun jde-java-font-lock-javadoc-link-keyword ()
   "Return a font lock keyword for javadoc @link tags.
@@ -356,7 +399,7 @@ Only fontify javadoc comments."
       (jde-java-font-lock-search-in-javadoc
        "{\\(@link\\)\\>[ \t]+\\([^}]*\\)}"
        end))
-    (1 font-lock-constant-face t)
+    (1 jde-java-font-lock-doc-tag-face t)
     (2 jde-java-font-lock-link-face t)))
 
 (defun jde-java-font-lock-javadoc-see-ref-keyword ()
@@ -484,7 +527,7 @@ because of incompatible regular expressions returned by `regexp-opt'."
   (and jde-java-font-lock-api-file
        (format "%s.%semacs-%d.apicache"
                jde-java-font-lock-api-file
-               (if jde-xemacsp "x" "")
+               (if (featurep 'xemacs) "x" "")
                emacs-major-version)))
 
 (defconst jde-java-font-lock-api-cache-file-header
@@ -539,10 +582,7 @@ is created."
           (message "jde-java-font-lock: building names cache...")
           (when (setq jde-java-font-lock-api-cache
                       (jde-java-font-lock-api-build-regexps
-                       ;; WARNING: It seems XEmacs search fails with a
-                       ;; very long regexp.  So get regexps for groups
-                       ;; of up to 200 names.
-                       (if jde-xemacsp 200 0)))
+                       jde-java-font-lock-max-names-by-regexp))
             ;; Save regexps in cache
             (with-current-buffer (find-file-noselect cache)
               (erase-buffer)
@@ -573,6 +613,27 @@ expressions."
 (defvar java-font-lock-keywords-4 nil
   "Extra level fontification keywords for JDE mode.")
 
+(defun jde-java-font-lock-refontify ()
+  "Update fontification of buffers in `java-mode' and `jde-mode'."
+  (let ((l (buffer-list))
+        b)
+    (while l
+      (setq b (car l)
+            l (cdr l))
+      (if (buffer-live-p b)
+          (with-current-buffer b
+            (if (and font-lock-mode
+                     (memq major-mode '(java-mode jde-mode)))
+                (progn
+                  (message
+                   "jde-java-font-lock: updating fontification of buffer %s..."
+                   (buffer-name))
+                  (font-lock-mode nil)
+                  (font-lock-mode 1)
+                  (message
+                   "jde-java-font-lock: updating fontification of buffer %s...done"
+                   (buffer-name)))))))))
+
 ;;;###autoload
 (defun jde-java-font-lock-setup-keywords (&optional rebuild)
   "Setup font lock keywords in `java-font-lock-keywords-4'.
@@ -590,12 +651,14 @@ expressions."
     ;; constants, Modifiers and Packages from keywords-1 will catch
     ;; them.
 ;;; Compatibility
-    (if jde-xemacsp
+    (if (featurep 'xemacs)
         (list
             
          ;; Special keywords and constants
-         '("\\<\\(this\\|super\\)\\>" (1 font-lock-keyword-face))
-         '("\\<\\(false\\|null\\|true\\)\\>" (1 font-lock-constant-face))
+         '("\\<\\(this\\|super\\)\\>"
+           (1 font-lock-keyword-face))
+         '("\\<\\(false\\|null\\|true\\)\\>"
+           (1 jde-java-font-lock-constant-face))
          ))
        
     (list
@@ -626,22 +689,24 @@ expressions."
                         "volatile"
                         )))
                    "\\)\\>")
-           'font-lock-builtin-face)
+           'jde-java-font-lock-modifier-face)
         
      ;; Fontify package directives
-     '("\\<\\(package\\)\\>[ \t]*\\(\\sw+\\)?"
+     '("\\<\\(package\\)\\>\\s-+\\(\\sw+\\)"
        (1 font-lock-keyword-face)
-       (2 font-lock-constant-face nil t)
+       (2 jde-java-font-lock-package-face nil t)
        ("\\=\\.\\(\\sw+\\)" nil nil
-        (1 font-lock-constant-face nil t)))
+        (1 jde-java-font-lock-package-face nil t)))
         
      ;; Fontify import directives
-     '("\\<\\(import\\)\\>[ \t]*\\(\\sw+\\)?"
+     '("\\<\\(import\\)\\>\\s-+\\(\\sw+\\)"
        (1 font-lock-keyword-face)
-       (2 font-lock-constant-face nil t)
+       (2 (if (equal (char-after (match-end 0)) ?\.)
+              'jde-java-font-lock-package-face
+            'font-lock-type-face))
        ("\\=\\.\\(\\*\\|\\sw+\\)" nil nil
         (1 (if (equal (char-after (match-end 0)) ?\.)
-               'font-lock-constant-face
+               'jde-java-font-lock-package-face
              (if (equal (char-before (match-end 0)) ?\*)
                  'jde-java-font-lock-number-face
                'font-lock-type-face)))))
@@ -651,7 +716,7 @@ expressions."
     (jde-java-font-lock-api-keywords rebuild)
        
 ;;; Compatibility
-    (if jde-xemacsp
+    (if (featurep 'xemacs)
         java-font-lock-keywords-2
       ;; Remove existing javadoc font lock keywords from FSF Emacs
       ;; `java-font-lock-keywords-3'
@@ -659,7 +724,7 @@ expressions."
        java-font-lock-keywords-3))
 
 ;;; Compatibility
-    (if jde-xemacsp
+    (if (featurep 'xemacs)
         nil
       ;; FSF Emacs don't fontify capitalized types so do it
       (list
@@ -687,21 +752,29 @@ expressions."
     (list
         
      ;; Fontify numbers
-     (cons
-      (concat "\\b\\(0[xX][0-9a-fA-F]+[lL]?\\|[0-9]+\\.?[0-9]*"
-              "\\([eE][-+]?[0-9]+\\)?\\([lL]\\|[fF]\\|[dD]\\)?\\)\\b")
-      'jde-java-font-lock-number-face)
-     (cons
-      (concat "\\b\\(\\.[0-9]+"
-              "\\([eE][-+]?[0-9]+\\)?\\([lL]\\|[fF]\\|[dD]\\)?\\)\\b")
-      'jde-java-font-lock-number-face)
+     '("\\<[0-9]+[.][0-9]+\\([eE][-+]?[0-9]+\\)?[fFdD]?\\>"
+       . jde-java-font-lock-number-face)
+     '("\\<[0-9]+[.][eE][-+]?[0-9]+[fFdD]?\\>"
+       . jde-java-font-lock-number-face)
+     '("\\<[0-9]+[.][fFdD]\\>"
+       . jde-java-font-lock-number-face)
+     '("\\<[0-9]+[.]"
+       . jde-java-font-lock-number-face)
+     '("[.][0-9]+\\([eE][-+]?[0-9]+\\)?[fFdD]?\\>"
+       . jde-java-font-lock-number-face)
+     '("\\<[0-9]+[eE][-+]?[0-9]+[fFdD]?\\>"
+       . jde-java-font-lock-number-face)
+     '("\\<0[xX][0-9a-fA-F]+[lL]?\\>"
+       . jde-java-font-lock-number-face)
+     '("\\<[0-9]+[lLfFdD]?\\>"
+       . jde-java-font-lock-number-face)
      
      ;; Fontify capitalised identifiers as constant
      (cons
       (concat "\\(\\b[" jde-java-font-lock-capital-letter
               "]+[" jde-java-font-lock-capital-letter-or-digit
               "]*\\b\\)")
-      '(1 font-lock-constant-face))
+      '(1 jde-java-font-lock-constant-face))
 
      ;; Fontify text between `' in comments
      (jde-java-font-lock-quote-keyword))
@@ -723,11 +796,9 @@ expressions."
      (jde-java-font-lock-javadoc-see-ref-keyword)
      ;; Fontify the text of a HREF anchor
      (jde-java-font-lock-html-ahref-keyword)
-     ;; Fontify <strong> style text
-     (jde-java-font-lock-html-strong-keyword)
-     ;; Fontify <b> style text
+     ;; Fontify <b> and <strong> style text
      (jde-java-font-lock-html-bold-keyword)
-     ;; Fontify <i> style text
+     ;; Fontify <i> and <em> style text
      (jde-java-font-lock-html-italic-keyword)
      ;; Fontify <u> style text
      (jde-java-font-lock-html-underline-keyword)
@@ -736,51 +807,54 @@ expressions."
      ;; Fontify <pre> style text
      (jde-java-font-lock-html-pre-keyword))
        
-    )))
+    ))
+  
+  ;; Update fontification of buffers in `java-mode' and `jde-mode'
+  (and (interactive-p)
+       (jde-java-font-lock-refontify)))
 
+;; Setup `java-font-lock-keywords-4'
 (jde-java-font-lock-setup-keywords)
 
-;; Setup JDE mode for font locking.  Copy `font-lock-defaults' from
-;; `java-mode' and add the new `java-font-lock-keywords-4' level in
-;; `jde-mode'.
+;; Define new defaults for Font Lock mode
+(defconst jde-java-font-lock-defaults
+  (let ((java-defaults 
+         (if (featurep 'xemacs)
+             (get 'java-mode 'font-lock-defaults)
+           (cdr (assq 'java-mode font-lock-defaults-alist)))))
+    (cons (append (car java-defaults) '(java-font-lock-keywords-4))
+          (cdr java-defaults)))
+  "Defaults for Font Lock mode specified by the major mode.
+Add `java-font-lock-keywords-4' level to Java `font-lock-defaults'.")
 
-(defun jde-java-font-lock-defaults (java-defaults)
-  "Return a new `font-lock-defaults' value from JAVA-DEFAULTS.
-That is add the new `java-font-lock-keywords-4' level."
-  (cons (append (car java-defaults) '(java-font-lock-keywords-4))
-        (cdr java-defaults)))
-
-;;; Compatibility
-;; XEmacs
-(if jde-xemacsp
-    (put 'jde-mode 'font-lock-defaults
-         (jde-java-font-lock-defaults
-          (get 'java-mode 'font-lock-defaults)))
-  
-  ;; FSF Emacs
-  (add-to-list
-   'font-lock-defaults-alist
-   (cons 'jde-mode
-         (jde-java-font-lock-defaults
-          (cdr (assq 'java-mode font-lock-defaults-alist)))))
-  )
-                 
+;; Mode hook to setup syntax coloring.  Automatically run by
+;; `jde-mode' if `jde-use-font-lock' is non-nil.
 (defun jde-setup-syntax-coloring()
   "Set up JDE mode syntax coloring."
-  (cond (window-system
-         
-	 ;; If not XEmacs 20.1 turn on font lock.
-	 ;; (XEmacs 21 has font-lock on by default.)
-	 (if (or
-	      (not jde-xemacsp)
-	      (not
-	       (and
-		(eq emacs-major-version 21)
-		(eq emacs-minor-version 0))))
-	     (turn-on-font-lock))
-
-	 (setq font-lock-maximum-decoration t))))
+  (if window-system
+      (progn
+        ;; Setup `font-lock-defaults'
+        (set (make-local-variable 'font-lock-defaults)
+             jde-java-font-lock-defaults)
+        ;; Use the maximum decoration available
+        (set (make-local-variable 'font-lock-maximum-decoration)
+             t)
+        ;; Turn on Font Lock Mode as needed 
+        (if (and (boundp 'global-font-lock-mode)
+                 (symbol-value 'global-font-lock-mode)
+                 (let ((flgm (and (boundp 'font-lock-global-modes)
+                                  (symbol-value 'font-lock-global-modes))))
+                   (or (eq flgm t)
+                       (if (eq (car-safe flgm) 'not)
+                           (not (memq major-mode (cdr flgm)))
+                         (memq major-mode flgm)))))
+            ;; Already enabled by `global-font-lock-mode'.
+            nil
+          ;; Turn it on.
+          (turn-on-font-lock)))))
 
+;; To use JDE mode syntax coloring in Java mode
+(add-hook 'java-mode-hook 'jde-setup-syntax-coloring)
 
 (provide 'jde-java-font-lock)
 
@@ -788,8 +862,42 @@ That is add the new `java-font-lock-keywords-4' level."
 
 ;;
 ;; $Log: jde-java-font-lock.el,v $
-;; Revision 1.1  2001/02/12 05:45:05  paulk
-;; Initial XEmacs revision.
+;; Revision 1.2  2001/08/16 03:29:19  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.5  2001/04/14 05:28:11  paulk
+;; - All extra fontification added by jde-java-font-lock have a specific
+;;   face.  So there is less font-lock implementation dependencies,
+;;   greater flexibility to setup a color theme, and fontification can be
+;;   kept consistent accross Emacs flavors :-) Notice that this change
+;;   may require to redo some face customization :(
+;;
+;;
+;; - For convenience all specific jde-java-font-lock faces are in the
+;;   customization group `jde-java-font-lock-faces' which is a sub group
+;;   of `font-lock-highlighting-faces' (Emacs) or `font-lock-faces'
+;;   (XEmacs).
+;;
+;;
+;; - Better fontification of numbers and imported package names.
+;;
+;;
+;; - When used interactively the command
+;;   `jde-java-font-lock-setup-keywords' automatically update
+;;   fontification of all Java buffers.  This is very useful when you
+;;   change your API file for example!
+;;
+;;
+;; - The `jde-setup-syntax-coloring' is greatly enhanced.  On Emacs, it
+;;   takes care of the current `global-font-lock-mode' setting.  Also, it
+;;   no more use `font-lock-defaults-alist' (which is an obsolete
+;;   variable on Emacs 21) but the preferred `font-lock-defaults' way to
+;;   setup fontification.
+;;
+;; - Finally, jde-java-font-lock works in java-mode too and it can be
+;;   used standalone if needed.
+;;
+;; Contributed by David Ponce.
 ;;
 ;; Revision 1.4  2001/01/17 18:59:03  paulk
 ;; Font-locking improvements from David Ponce
@@ -827,4 +935,4 @@ That is add the new `java-font-lock-keywords-4' level."
 ;; Initial revision.
 ;;
 
-;;; jde-java-font-lock.el ends here
\ No newline at end of file
+;;; jde-java-font-lock.el ends here
