@@ -1,5 +1,5 @@
 ;;; jde-parse.el
-;; $Revision: 1.2 $ 
+;; $Revision: 1.3 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -70,6 +70,7 @@ JDE to parse a buffer automatically regardless of its size."
   ;; in some versions of XEmacs. Hence the following 
   ;; guard.
   (when (string= mode-name "JDE")
+    (message "Test parse buffer")
     (semantic-clear-toplevel-cache)
     (semantic-bovinate-toplevel)))
 
@@ -143,7 +144,7 @@ current session."
   (mapcan (lambda (buffer)
 	  (save-excursion
 	    (set-buffer buffer)
-	    (if (string= mode-name "JDE")
+	    (if (equal major-mode 'jde-mode)
 		(list buffer))))
 	  (buffer-list)))
 
@@ -160,7 +161,7 @@ current session."
   (let ((selected-buffer (window-buffer (selected-window))))
     (save-excursion
       (set-buffer selected-buffer)
-      (if (string= mode-name "JDE") selected-buffer))))
+      (if (equal major-mode 'jde-mode) selected-buffer))))
 
 (defun jde-parse-get-package-name ()
   "Gets the name of the package in which the Java source file in the
@@ -626,8 +627,11 @@ in a method; otherwise, nil."
 (provide 'jde-parse)
 
 ;; $Log: jde-parse.el,v $
-;; Revision 1.2  2001/02/12 05:38:26  paulk
-;; JDE 2.2.7
+;; Revision 1.3  2001/08/16 03:29:20  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.30  2001/03/16 04:49:08  paulk
+;; Use major-mode instead of mode-name for testing which mode buffer is in. Thanks to Kevin Burton burton@relativity.yi.org.
 ;;
 ;; Revision 1.29  2001/01/05 07:14:35  paulk
 ;; Removed old version of jde-parse-get-class-at-point.
