@@ -1,5 +1,5 @@
 ;; jde-run.el --- runs the Java app in the current buffer.
-;; $Revision: 1.3 $ $Date: 2001/02/12 05:38:26 $
+;; $Revision: 1.4 $ $Date: 2001/08/16 03:29:21 $
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -381,15 +381,21 @@ Run Option panel variables."
     ;; Set the classpath option. Use the local
     ;; classpath, if set; otherwise, the global
     ;; classpath.
-    (setq options
-	  (nconc
-	   options
-	   (list
-	    "-classpath"
-	    (jde-build-classpath
-	     (if jde-run-option-classpath
+    (let ((classpath
+	   (if jde-run-option-classpath
 		 jde-run-option-classpath
-	       jde-global-classpath)))))
+	       jde-global-classpath))
+	  (symbol
+	   (if jde-run-option-classpath
+		 'jde-run-option-classpath
+	       'jde-global-classpath)))
+      (if classpath
+	  (setq options
+		(nconc
+		 options
+		 (list
+		  "-classpath"
+		  (jde-build-classpath classpath symbol))))))
     
 
     ;; Set the verbose options.
@@ -516,17 +522,28 @@ Run Option panel variables."
 
 
 ;;;###autoload
-(defun jde-run ()
+(defun jde-run (main-class)
   "Run the Java application specified by `jde-run-executable', if
 not the null string. Otherwise run the class specified by 
 `jde-run-application-class', if non-null; otherwise the class in
-the current buffer. This command also creates a comint buffer to allow
-you to interacti with the program."
-  (interactive)
-  (if (string= mode-name "JDE")
-      (if (string= jde-run-executable "")
-	  (jde-run-main-class)
-	(jde-run-executable))
+the current buffer. Specifying a prefix argument, e.g.,
+C-u C-c C-v C-r, causes this command to prompt you to enter
+the name of the application's main class This command 
+creates a comint buffer to allow you to interacti with the program."
+  (interactive "P")
+  (if (equal major-mode 'jde-mode)
+      (cond
+       (main-class
+	(jde-run-internal
+	 (read-from-minibuffer
+	  "Main class: "
+	  (concat (jde-db-get-package)
+		      (file-name-sans-extension 
+		       (file-name-nondirectory (buffer-file-name)))))))
+      ((string= jde-run-executable "")
+       (jde-run-main-class))
+      (t 
+       (jde-run-executable)))
     (error "The jde-run command works only in a Java source buffer.")))
 
 (defun jde-run-get-main-class () 
@@ -576,7 +593,7 @@ buffer belongs is running."
 	(source-directory default-directory)
 	(working-directory (if (string= jde-run-working-directory "")
 			       default-directory
-			     jde-run-working-directory)))
+			     (jde-normalize-path 'jde-run-working-directory))))
     (if (not (comint-check-proc run-buf-name))
 	(let* ((run-buffer (get-buffer-create run-buf-name))
 	       (win32-p (eq system-type 'windows-nt))
@@ -633,7 +650,7 @@ buffer belongs is running."
 	 (source-directory default-directory)
 	 (working-directory (if (string= jde-run-working-directory "")
 				default-directory
-			      jde-run-working-directory)))
+			      (jde-normalize-path 'jde-run-working-directory))))
     (if (not (comint-check-proc run-buf-name))
 	(let* ((run-buffer (get-buffer-create run-buf-name))
 	       (prog-args (append
@@ -665,14 +682,19 @@ buffer belongs is running."
       (pop-to-buffer run-buf-name))))
 
 
-;;;###autoload
-(defun jde-run-mode()
+(defun jde-run-mode-internal()
   "Mode for running Java programs."
-  (interactive)
-  (comint-mode)
-  (setq major-mode 'jde-run-mode)
-  (run-hooks 'jde-run-mode-hook)
-)
+  (define-key (current-local-map) "\C-c\C-v\C-[" 'jde-run-etrace-prev)
+  (define-key (current-local-map) "\C-c\C-v\C-]" 'jde-run-etrace-next)
+  (define-key (current-local-map) [mouse-2] 'jde-run-etrace-show-at-mouse)
+  (font-lock-mode 1)
+  (jde-run-etrace-setup-font-lock))
+
+(define-derived-mode 
+  jde-run-mode comint-mode "JDE Run Mode"
+  "Major mode for running Java applications and applets.
+  \\{jde-run-mode-map}"
+  (jde-run-mode-internal))
 
 (defun jde-get-appletviewer-options ()
   (let (options)
@@ -838,13 +860,153 @@ file."
   (jde-run-applet))
    
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;                                                                      ;;
+;;  Exception Trace Navigation                                          ;;
+;;                                                                      ;;           
+;;  Copyright (C) 1999 Phillip Lord <p.lord@hgmp.mrc.ac.uk>             ;; 
+;;  Copyright (C) 2001 Sam Steingold <sds@gnu.org>                      ;;              
+;;  Copyright (C) 2001 Kevin A. Burton <burton@apache.org>              ;;
+;;                                                                      ;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;           
+(defvar jde-run-etrace-current-marker (cons (make-marker) (make-marker))
+  "The location of the last stack shown.
+A cons of two markers, location of the error and the location in the code.")
+
+
+(defun jde-run-etrace-current-marker (&optional next)
+  "Update the `cdr' of `jde-run-etrace-current-marker' from its `car'.
+Here goes all the error message parsing."
+  (let ((here (car jde-run-etrace-current-marker))
+        (there (cdr jde-run-etrace-current-marker)))
+    (save-excursion
+      (set-buffer (marker-buffer here))
+      (goto-char here)
+      (forward-line (or next 0))
+      (re-search-forward
+       (eval-when-compile
+        (concat "\\([a-zA-Z0-9_.]+\\.\\)?" ; package
+                "\\([a-zA-Z0-9_]+\\)" ; class
+                "\\.<?[a-zA-Z0-9_]+>?" ; method
+                "(\\([a-zA-Z0-9_]+\\)\\.java:" ; java file = public class
+                "\\([0-9]+\\))"))
+       nil t) ; line number
+      (message "1: [%s]; 2: [%s]; 3: [%s]; 4: [%s]" (match-string 1)
+               (match-string 2) (match-string 3) (match-string 4))
+      (let* ((package (or (match-string 1) ""))
+            (class (match-string 2))
+            (file-name (match-string 3))
+            (line (car (read-from-string (match-string 4))))
+            (file (jde-find-class-source-file (concat package file-name)))
+	    (buf (if file (find-file-noselect file)
+                    (error "jde-class-source cannot find source for %s%s (%s)"
+                           package class file-name))))
+	(set-buffer buf) (goto-line line)
+	(set-marker there (point) buf)))
+    jde-run-etrace-current-marker))
+
+
+(defun jde-run-etrace-goto (&optional next)
+  "Display the current stack using `compilation-goto-locus'."
+  (compilation-goto-locus (jde-run-etrace-current-marker next)))
+
+
+(defun jde-run-etrace-show-at-mouse (event)
+  "Jump to the stack position at the mouse click.
+Click anywhere on the line with the stack reference."
+  (interactive "e")
+  (set-marker (car jde-run-etrace-current-marker)
+              (posn-point (event-start event))
+              (window-buffer (posn-window (event-start event))))
+  (jde-run-etrace-goto))
+
+
+(defun jde-run-etrace-show-at-point ()
+  "Jump to the stack position on this current line.
+The point should be anywhere on the line with the stack reference."
+  (interactive)
+  (set-marker (car jde-run-etrace-current-marker) (point) (current-buffer))
+  (jde-run-etrace-goto))
+
+
+(defun jde-run-etrace-next ()
+  "Jump to the next stack postion (next line)."
+  (interactive)
+  (jde-run-etrace-goto 1))
+
+
+(defun jde-run-etrace-prev ()
+  "Jump to the previous stack postion (previous line)."
+  (interactive)
+  (jde-run-etrace-goto -1))
+
+(defun jde-run-etrace-setup-font-lock ()
+    ;;setup the correct font-lock stuff
+
+
+  ;;font lock setup notes
+  ;;
+  ;; the actual exception class -> font-lock-keyword-face
+  ;; exception message -> font-lock-string-face
+  ;; stack entry class and method -> font-lock-constant-face
+  ;; stack entry file -> font-lock-variable-name-face
+  ;; stack entry line number -> font-lock-type-face
+
+  (if jde-xemacsp
+      nil
+    (progn
+      (font-lock-add-keywords 
+       nil 
+       '(("\\(^[a-z.]+[a-zA-Z0-9]+Exception\\)\\(: \\)?\\(.*\\)?"
+	  (1 'font-lock-keyword-face append)
+	  (3 'font-lock-string-face append))))
+  
+      (font-lock-add-keywords 
+       nil 
+       '(("\\(at [a-z.]+[a-zA-Z0-9]+\\.[a-zA-Z<>]*\\)(\\([a-zA-Z0-9]+.java\\):\\([0-9]+\\))$"
+	  (1 'font-lock-constant-face append)
+	  (2 'font-lock-variable-name-face append)
+	  (3 'font-lock-type-face append))))
+      (font-lock-fontify-buffer))))
+
+;;(define-key jde-mode-map "\C-c\C-v\C-[" 'jde-run-etrace-prev)
+;;(define-key jde-mode-map "\C-c\C-v\C-]" 'jde-run-etrace-next)
+
+
 (provide 'jde-run)
 
 
 ;; Change History
 ;; $Log: jde-run.el,v $
-;; Revision 1.3  2001/02/12 05:38:26  paulk
-;; JDE 2.2.7
+;; Revision 1.4  2001/08/16 03:29:21  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.52  2001/04/28 06:22:19  paulk
+;; Makes jde-run-mode a full-fledged major mode derived from comint-mode.
+;;
+;; Revision 1.51  2001/04/16 06:00:50  paulk
+;; Normalize paths. Thanks to Nick Sieger.
+;;
+;; Revision 1.50  2001/04/12 04:37:45  paulk
+;; Normalize jde-run-working-directory.
+;;
+;; Revision 1.49  2001/04/11 03:18:04  paulk
+;; Updated to resolve relative paths relative to the project file that defines them. Thanks to Nick Seiger.
+;;
+;; Revision 1.48  2001/04/09 05:28:20  paulk
+;; 
+;; Revision 1.47  2001/03/16 04:52:46  paulk
+;; Use major-mode instead of mode-name to check the buffer mode. Thanks to Kevin Burton.
+;;
+;; Revision 1.46  2001/03/02 04:10:37  paulk
+;; Updated jde-run prompt to specify the class in the current buffer as the suggested response.
+;;
+;; Revision 1.45  2001/03/01 12:50:20  paulk
+;; The jde-run command now prompts you to enter the name of the
+;; application's main class if you type a prefix (C-u) first.
+;;
+;; Revision 1.44  2001/02/26 04:13:11  paulk
+;; jde-run now handles case where jde-global-classpath and jde-run-option-classpath are nil.
 ;;
 ;; Revision 1.43  2001/02/03 08:23:53  paulk
 ;; Changed declaration of customized variables so you can use completion on path variables.
