@@ -1,5 +1,5 @@
 ;;; jde-widgets.el -- Custom-style widgets used by the JDE
-;; $Revision: 1.3 $ $Date: 2001/02/17 07:38:21 $ 
+;; $Revision: 1.4 $ $Date: 2001/08/16 03:29:21 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -40,6 +40,7 @@
 (require 'wid-edit)
 (require 'eieio)
 (require 'cl)
+(require 'tree-widget)
 
 
 ;; ----------------------------------------------------------------------
@@ -245,6 +246,55 @@ default method kills the dialog buffer."
    (pop-to-buffer (oref this buf)))
 
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;                                                                            ;; 
+;; Option Dialog                                                              ;;
+;;                                                                            ;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(defclass jde-option-dialog (jde-dialog)
+  ((options       :initarg :options
+		  :documentation
+		  "Options from from which to choose.")		  
+   (radio-buttons :initarg :interface-buttons
+		  :documentation
+		  "Buttons for selecting options.")
+   (text          :initarg :text
+		  :type string
+		  :initform "Select option."
+		  :documentation
+		  "Text to be inserted at top of dialog.")
+   (ok-action     :initarg :ok-action
+		  :type function
+		  :documentation
+		  "Function to invoke when the user selects the ok button."))
+   "This dialog allows a user to choose one of a set of OPTIONS by clicking
+a radio button next to the option. The dialog invokes the function OK-ACTION
+when the user selects the OK button on the dialog. OK-ACTION must be a function
+that takes the selected option as its only argument.")
+
+(defmethod initialize-instance ((this jde-option-dialog) &rest fields)
+  "Dialog constructor."
+  (call-next-method))
+
+(defmethod jde-dialog-create ((this jde-option-dialog))
+  (widget-insert (oref this text))
+  (widget-insert "\n\n")
+  (oset this radio-buttons
+ 	(widget-create
+ 	 (list
+	  'radio-button-choice
+	  :value (car (oref this options))
+	  :args (mapcar 
+		 (lambda (x) 
+		   (list 'item x)) 
+		 (oref this options)))))
+  (widget-insert "\n"))
+
+(defmethod jde-dialog-ok ((this jde-option-dialog))
+  (funcall (oref this ok-action) 
+	   (widget-value (oref this radio-buttons))))
+
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;                                                                            ;; 
@@ -343,45 +393,47 @@ tree."
 		       :process process
 		       :object-id (oref var-value id)))
 		 (str-val (jde-dbs-cmd-exec cmd)))
-	    (list 'jde-widget-tree :tag var-tag :value t
-		  (list 'jde-widget-tree :tag str-val)))
+	    (list 'tree-widget :tag var-tag :value t
+		  (list 'tree-widget :tag str-val)))
 	(list 'jde-widget-java-obj :tag var-tag
 	      :process process :object-id (oref var-value :id))))
      ((typep var-value 'jde-dbs-java-array)
       (list 'jde-widget-java-array :tag var-tag
 	    :process process :object var-value))
      ((typep var-value 'jde-dbs-java-primitive)
-      (list 'jde-widget-tree :tag var-tag :value t
-	    (list 'jde-widget-tree 
+      (list 'tree-widget :tag var-tag :value t
+	    (list 'tree-widget 
 		  :tag (format "%s" (oref var-value value)))))
      ((typep var-value 'jde-dbs-java-null)
-      (list 'jde-widget-tree :tag var-tag :value t
-	    (list 'jde-widget-tree :tag "null")))
+      (list 'tree-widget :tag var-tag :value t
+	    (list 'tree-widget :tag "null")))
      (t
       (error "Unidentified type of local variable: %s" var-tag)))))
 
-(defun jde-widget-java-obj-get-fields (tree-widget)
-  (let* ((process (widget-get tree-widget :process))
-	 (object-id (widget-get tree-widget :object-id))
-	 (cmd
-	  (jde-dbs-get-object
-	   (format "get_object %d" object-id)
-	   :process process
-	   :object-id object-id))
-	 (object
-	  (jde-dbs-cmd-exec cmd))
-	 (fields (oref object fields))
-	 field
-	 nodes)
-    (while fields
-      (setq field (car fields) fields (cdr fields)) 
-      (setq field (cdr field))
-      (push 
-       (jde-widget-java-var-to-tree process field)
-       nodes)) 
-    nodes))
+(defun jde-widget-java-obj-get-fields (obj-widget)
+  (if (widget-get obj-widget :args)
+      (widget-get obj-widget :args)
+    (let* ((process (widget-get obj-widget :process))
+	   (object-id (widget-get obj-widget :object-id))
+	   (cmd
+	    (jde-dbs-get-object
+	     (format "get_object %d" object-id)
+	     :process process
+	     :object-id object-id))
+	   (object
+	    (jde-dbs-cmd-exec cmd))
+	   (fields (oref object fields))
+	   field
+	   nodes)
+      (while fields
+	(setq field (car fields) fields (cdr fields)) 
+	(setq field (cdr field))
+	(push 
+	 (jde-widget-java-var-to-tree process field)
+	 nodes)) 
+      nodes)))
 
-(define-widget 'jde-widget-java-obj 'jde-widget-dtree
+(define-widget 'jde-widget-java-obj 'tree-widget
   "A widget that represents a Java object.
 This widget is essentially a tree node whose entries are the fields
 of the corresponding object. The first time the user expands the node,
@@ -392,7 +444,8 @@ user closes and then reopens the node. Use the syntax
 :tag NAME :process PROCESS :object-id OBJ-ID) to create the widget where
 NAME is the object's name, PROCESS is the process in which
 the object exists, and  ID is the debugger id for the object."
-  :node-fcn 'jde-widget-java-obj-get-fields)
+  :dynargs 'jde-widget-java-obj-get-fields
+  :has-children t)
 
 
 (defun jde-widget-java-array-element-to-tree (process element index)
@@ -404,7 +457,7 @@ the object exists, and  ID is the debugger id for the object."
 		       :process process
 		       :object-id (oref element id)))
 		 (str-val (jde-dbs-cmd-exec cmd)))
-	    (list 'jde-widget-tree :tag (format "[%d] %s" index str-val)))
+	    (list 'tree-widget :tag (format "[%d] %s" index str-val)))
 	(list 'jde-widget-java-obj 
 	      :tag (format "[%d] %s" index (oref element jtype))
 	      :process process :object-id (oref element id))))
@@ -413,55 +466,58 @@ the object exists, and  ID is the debugger id for the object."
 	    :tag (format "[%d] %s" index (oref element jtype))
 	    :process process :object element))
      ((typep element 'jde-dbs-java-primitive)
-      (list 'jde-widget-tree :tag (format "[%d] %s"  index (oref element value))))
+      (list 'tree-widget :tag (format "[%d] %s"  index (oref element value))))
      ((typep element 'jde-dbs-java-null)
-      (list 'jde-widget-tree :tag (format "[%d] null" index)))
+      (list 'tree-widget :tag (format "[%d] null" index)))
      (t
       (error "Unidentified type of object: <%s|%s>" (oref element jtype) 
 	     (oref element id)))))
 
-(defun jde-widget-java-array-get-elements (tree-widget)
-  (let* ((process (widget-get tree-widget :process))
-	 (array (widget-get tree-widget :object))
-	 cmd array-length)
+(defun jde-widget-java-array-get-elements (array-widget)
+  (if (widget-get array-widget :args)
+      (widget-get array-widget :args)
+    (let* ((process (widget-get array-widget :process))
+	   (array (widget-get array-widget :object))
+	   cmd array-length)
 
-    (setq cmd
-	 (jde-dbs-get-array 
-	   (format "get_array_length %d" (oref array id))
-	   :process process
-	   :array array))
-    (jde-dbs-cmd-exec cmd) 
-
-    (setq array-length
-	  (if (slot-boundp array 'length)
-	     (oref array length)
-	    0))
-    
-    (when (> array-length 0)
       (setq cmd
-	  (jde-dbs-get-array 
-	   (format "get_array_elements %d" (oref array id))
-	   :process process
-	   :array array
-	   :index 0
-	   :length array-length))
-      (jde-dbs-cmd-exec cmd)
-      (let ((elements (oref array elements))
-	    element
-	    nodes 
-	    (index 0))
-	(while elements
-	  (setq element (car elements) elements (cdr elements)) 
-	  (setq nodes 
-		(append nodes 
-			(list (jde-widget-java-array-element-to-tree process element index))))
-	  (setq index (1+ index))) 
-	nodes))))
+	    (jde-dbs-get-array 
+	     (format "get_array_length %d" (oref array id))
+	     :process process
+	     :array array))
+      (jde-dbs-cmd-exec cmd) 
 
-(define-widget 'jde-widget-java-array 'jde-widget-dtree
+      (setq array-length
+	    (if (slot-boundp array 'length)
+		(oref array length)
+	      0))
+    
+      (when (> array-length 0)
+	(setq cmd
+	      (jde-dbs-get-array 
+	       (format "get_array_elements %d" (oref array id))
+	       :process process
+	       :array array
+	       :index 0
+	       :length array-length))
+	(jde-dbs-cmd-exec cmd)
+	(let ((elements (oref array elements))
+	      element
+	      nodes 
+	      (index 0))
+	  (while elements
+	    (setq element (car elements) elements (cdr elements)) 
+	    (setq nodes 
+		  (append nodes 
+			  (list (jde-widget-java-array-element-to-tree process element index))))
+	    (setq index (1+ index))) 
+	  nodes)))))
+
+(define-widget 'jde-widget-java-array 'tree-widget
   "A widget that represents a Java array. Clicking on the widget's
 expand button causes the widget to display the values of the array."
-  :node-fcn 'jde-widget-java-array-get-elements)
+  :dynargs 'jde-widget-java-array-get-elements
+  :has-children t)
 
 (defun test-obj ()
   (interactive)
@@ -608,8 +664,14 @@ expand button causes the widget to display the values of the array."
 (provide 'jde-widgets)
 
 ;; $Log: jde-widgets.el,v $
-;; Revision 1.3  2001/02/17 07:38:21  paulk
-;; Requires cl to enable batch compile.
+;; Revision 1.4  2001/08/16 03:29:21  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.12  2001/05/21 06:44:29  paulk
+;; Added jde-option-dialog class.
+;;
+;; Revision 1.11  2001/04/19 04:37:14  paulk
+;; Converted array and object trees to derive from David Ponce's tree widget.
 ;;
 ;; Revision 1.10  2001/02/16 04:38:52  paulk
 ;; Added (require 'cl) to enable batch compile.
