@@ -1,11 +1,10 @@
 ;;; jde-wiz.el
-
-;; $Revision: 1.3 $
+;; $Revision: 1.4 $
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
 ;; Keywords: java, tools
 
-;; Copyright (C) 1997, 1998, 2000 Paul Kinnucan.
+;; Copyright (C) 1997, 1998, 2000, 2001 Paul Kinnucan.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -24,11 +23,7 @@
 
 (require 'beanshell)
 (require 'jde-complete)
-
-
-
-;;
-
+(require 'jde-widgets)
 
 (defun jde-wiz-escape-backslashes-in-path (path) 
   (mapconcat
@@ -45,11 +40,9 @@ defined by jde-global-classpath. Wizards use this list to resolve unqualified cl
     (message "Rescanning classes...")
     (bsh-eval (concat "jde.util.JdeUtilities.buildClassList("
 		      (jde-wiz-escape-backslashes-in-path
-		       (jde-build-path-arg nil jde-global-classpath t)
-)
+		       (jde-build-path-arg nil 'jde-global-classpath t))
                     ");"))
-    (message "Rescanning classes...Complete"))
-)
+    (message "Rescanning classes...Complete")))
 
 
 (defun jde-wiz-get-package-name ()
@@ -71,7 +64,6 @@ defined by jde-global-classpath. Wizards use this list to resolve unqualified cl
   (string-match "[^.]+$" name)
   (substring name (match-beginning 0) (match-end 0)))
 
-
 (defun jde-wiz-update-implements-clause (interface-name)
    (interactive
     "sEnter interface: ")
@@ -100,11 +92,8 @@ defined by jde-global-classpath. Wizards use this list to resolve unqualified cl
 	    (goto-char (- open-brace-pos 1))
 	      (insert (concat " implements " interface " "))))))))
 
-
-(defun jde-wiz-implement-interface (interface-name)
+(defun jde-wiz-generate-interface (interface-name)
   "*Generate a skeleton implementation of a specified interface."
-  (interactive
-   "sInterface name: ")
   (condition-case err
       (let* ((nl-brace-p
 	      (find 'before 
@@ -126,6 +115,36 @@ defined by jde-global-classpath. Wizards use this list to resolve unqualified cl
     (error
      (message "%s" (error-message-string err)))))
 
+(defun jde-wiz-implement-interface-internal (interface-name)
+  "*Generate a skeleton implementation of a specified interface."
+  (interactive
+   "sInterface name: ")
+  (condition-case err
+      (let ((names 
+	 (bsh-eval-r
+	  (format "jde.util.JdeUtilities.getQualifiedName(\"%s\");" interface-name ))))
+	(if names
+	    (if (> (length names) 1)
+		(let ((dialog
+		       (jde-option-dialog
+			"class name dialog"
+			:options names
+			:text "Select interface to implement."
+			:ok-action 'jde-wiz-generate-interface)))
+		  (jde-dialog-show dialog))
+	      (jde-wiz-generate-interface (car names)))
+	  (error "Cannot find interface %s on jde-global-classpath." interface-name)))
+    (error
+     (message "%s" (error-message-string err)))))
+
+(defun jde-wiz-implement-interface (interface-name)
+  "*Generate a skeleton implementation of a specified interface."
+  (interactive
+   "sInterface name: ")
+  (jde-wiz-implement-interface-internal interface-name)
+  (goto-char (scan-lists (point) -1 1))
+  (c-indent-exp))
+
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Method override wizard                                                  ;;
@@ -145,9 +164,8 @@ defined by jde-global-classpath. Wizards use this list to resolve unqualified cl
 		     (match-beginning 1)
 		     (match-end 1))))))))
 
-
-(defun jde-wiz-override-method (method-name)
-  "Overrides a method whose name you specify.
+(defun jde-wiz-override-method (method-name) 
+ "Overrides a method whose name you specify.
 This command creates a skeleton implementation of the
 overridden method at point. This command infers the
 qualified name of the class of the overriden method by 
@@ -168,14 +186,12 @@ import statement does not already exist in the file.
 NOTE: this command works only if the overriding class 
       has been previously compiled."
   (interactive
-   "sMethod name: ")
+   "sMethod name: " )
   (condition-case err
-      (let* ((package-name (jde-wiz-get-package-name))
-	     (class-name (jde-wiz-get-method-class))
-	     (qualified-class-name 
-	      (if (and package-name class-name)
-		  (concat package-name "." class-name)
-		class-name)))
+      (let* ((class-name 
+	      (jde-parse-get-super-class-at-point))
+	     (qualified-class-name
+	      (jde-complete-get-qualified-name class-name)))
 	(if qualified-class-name
 	    (let ((signatures
 		   (bsh-eval
@@ -185,10 +201,12 @@ NOTE: this command works only if the overriding class
 	      (if signatures
 		  (if (> (length signatures) 1)
 		      (jde-wiz-override-variant-method signatures)
-		    (jde-wiz-override-method-internal (car signatures)  signatures))))))
+		    (jde-wiz-override-method-internal (car signatures)  signatures))))
+	  (error "Cannot find parent class %s" class-name)))
     (error
      (message "%s" (error-message-string err)))))
 
+
 (defun jde-wiz-override-method-internal (selected-method methods)
   (let* ((variant
 	(position selected-method methods :test 'string=))
@@ -208,6 +226,8 @@ NOTE: this command works only if the overriding class
 	  (bsh-eval-r
 	   "jde.wizards.MethodOverrideFactory.getImportedClasses();")))
     (insert skeleton)
+    (goto-char (scan-lists (point) -1 1))
+    (c-indent-exp)
     (if required-imports
 	(jde-import-insert-imports required-imports))))
 
@@ -329,12 +349,37 @@ handling of those methods via attribute B."
     (error
      (message "%s" (error-message-string err)))))
 
+
+
   
 (provide 'jde-wiz)
 
+;;; Change History:
+
 ;; $Log: jde-wiz.el,v $
-;; Revision 1.3  2001/02/12 05:38:26  paulk
-;; JDE 2.2.7
+;; Revision 1.4  2001/08/16 03:29:21  andyp
+;; Update to JDE 2.2.7.1
+;;
+;; Revision 1.45  2001/05/23 05:14:00  paulk
+;; Updated jde-wiz-override-method-internal to intent the inserted code.
+;;
+;; Revision 1.44  2001/05/23 05:03:32  paulk
+;; Updated jde-wiz-implement-interface to indent the inserted code.
+;;
+;; Revision 1.43  2001/05/21 06:45:39  paulk
+;; Implement interface command now accepts unqualified interface names.
+;;
+;; Revision 1.42  2001/04/27 03:58:13  paulk
+;; Fixes Override Method Wizard so that it does not require a compiled version of the base class.
+;;
+;; Revision 1.41  2001/04/16 06:02:27  paulk
+;; Normalize paths. Thanks to Nick Sieger.
+;;
+;; Revision 1.40  2001/04/11 03:16:36  paulk
+;; Updated to resolve relative paths relative to the project file that defines them. Thanks to Nick Seiger.
+;;
+;; Revision 1.39  2001/03/13 03:45:06  paulk
+;; Cosmetic changes.
 ;;
 ;; Revision 1.38  2000/12/21 13:24:12  paulk
 ;; Changed jde-wiz-insert-imports to jde-import-insert-imports to reflect recent repackaging scheme.
